{*
 *******************************************************************************
 *
 *  Copyright 2023 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 *}
{*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 *
 *******************************************************************************
 *}

unit riegl.rdb.default.metadata;

{$WRITEABLECONST ON} // see section "initialization"

interface

// Meta data items definition version
const
  RDB_META_DATA_ITEMS_VERSION = '1.1.54';
  RDB_META_DATA_ITEMS_DATE = '2023-01-19';

// Meta data item states
const
  RDB_STATUS_REQUIRED = 1; // mandatory item
  RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
type
  TRDBPointcloudMetaDataItemInfo = record
    Name        : System.String;
    Title       : System.String;
    Description : System.String;
    Status      : System.Byte;
    Schema      : System.String;
    Example     : System.String;
  end;
  PRDBPointcloudMetaDataItemInfo = ^TRDBPointcloudMetaDataItemInfo;

// Angular notch filter parameters for window glass echoes
const
  RDB_RIEGL_ANGULAR_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.angular_notch_filter';
    Title       : 'Angular Notch Filter';
    Description : 'Angular notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"angle":{"type":"array","description":"Angle [deg]","it'
      + 'ems":{"type":"number"}},"range_mean":{"type":"array","description":"Me'
      + 'an range [m]","items":{"type":"number"}},"amplitude_mean":{"type":"arr'
      + 'ay","description":"Mean amplitude '
      + '[dB]","items":{"type":"number"}}},"description":"Angular notch filter '
      + 'parameters for window glass echoes","title":"Angular Notch Filter","re'
      + 'quired":["angle","range_mean","amplitude_mean"],"type":"object","$sche'
      + 'ma":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"angle":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0],"ran'
      + 'ge_mean":[0.094,0.094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,'
      + '0.0675,0.06475],"amplitude_mean":[3.780913,3.780913,3.480913,3.120913,'
      + '2.850913,2.720913,2.680913,2.610913,2.530913,2.570913,2.570913]}'
    );
  );

// Atmospheric parameters
const
  RDB_RIEGL_ATMOSPHERE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.atmosphere';
    Title       : 'Atmosphere';
    Description : 'Atmospheric parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"group_velocity":{"type":"number","description":"Group '
      + 'velocity of laser beam '
      + '[m/s]"},"pressure_sl":{"type":"number","description":"Atmospheric '
      + 'pressure at sea level '
      + '[mbar]"},"wavelength":{"type":"number","description":"Laser wavelength'
      + ' [nm]"},"rel_humidity":{"type":"number","description":"Relative '
      + 'humidity along measurement path '
      + '[%]"},"pressure":{"type":"number","description":"Pressure along '
      + 'measurment path '
      + '[mbar]"},"temperature":{"type":"number","description":"Temperature '
      + 'along measurement path '
      + '[\u00b0C]"},"attenuation":{"type":"number","description":"Atmospheric '
      + 'attenuation [1/km]"},"amsl":{"type":"number","description":"Height '
      + 'above mean sea level (AMSL) [m]"}},"description":"Atmospheric '
      + 'parameters","title":"Atmospheric Parameters","required":["temperature"'
      + ',"pressure","rel_humidity","pressure_sl","amsl","group_velocity","atte'
      + 'nuation","wavelength"],"type":"object","$schema":"http://json-schema.o'
      + 'rg/draft-04/schema#"}'
    );

    Example : (''
      + '{"group_velocity":299711000.0,"pressure_sl":970,"wavelength":1550,"rel'
      + '_humidity":63,"pressure":970,"temperature":7,"attenuation":0.028125,"a'
      + 'msl":0}'
    );
  );

// Laser beam geometry details
const
  RDB_RIEGL_BEAM_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.beam_geometry';
    Title       : 'Beam Geometry';
    Description : 'Laser beam geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"beam_divergence":{"type":"number","minimum":0,"exclusi'
      + 'veMinimum":false,"description":"Beam divergence in far field [rad]"},"'
      + 'beam_exit_diameter":{"type":"number","minimum":0,"exclusiveMinimum":fa'
      + 'lse,"description":"Beam width at exit aperture '
      + '[m]"}},"description":"Laser beam geometry details","title":"Beam Geome'
      + 'try","required":["beam_exit_diameter","beam_divergence"],"type":"objec'
      + 't","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"beam_divergence":0.0003,"beam_exit_diameter":0.0072}'
    );
  );

// List of control object type definitions
const
  RDB_RIEGL_CONTROL_OBJECT_CATALOG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_catalog';
    Title       : 'Control Object Catalog';
    Description : 'List of control object type definitions';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"types":{"type":"array","uniqueItems":true,"items":{"ty'
      + 'pe":"object","oneOf":[{"$ref":"#/definitions/rectangle"},{"$ref":"#/de'
      + 'finitions/checkerboard2x2"},{"$ref":"#/definitions/chevron"},{"$ref":"'
      + '#/definitions/circular_disk"},{"$ref":"#/definitions/cylinder"},{"$ref'
      + '":"#/definitions/sphere"},{"$ref":"#/definitions/round_corner_cube_pri'
      + 'sm"}]}}},"description":"List of control object type '
      + 'definitions","title":"Control Object Catalog","required":["types"],"ty'
      + 'pe":"object","$schema":"http://json-schema.org/draft-04/schema#","defi'
      + 'nitions":{"round_corner_cube_prism":{"type":"object","allOf":[{"$ref":'
      + '"#/definitions/common"},{"type":"object","properties":{"diameter":{"ty'
      + 'pe":"number","minimum":0,"exclusiveMinimum":true,"description":"diamet'
      + 'er in meters"},"offset":{"type":"number","description":"offset in '
      + 'meters, e.g. reflector constant (optional)"},"shape":{"type":"string",'
      + '"enum":["round_corner_cube_prism"],"description":"shape '
      + 'identifier"}},"description":"round corner cube prism specific '
      + 'properties","required":["shape","diameter"]}],"description":"round '
      + 'corner cube prism"},"cylinder":{"type":"object","allOf":[{"$ref":"#/de'
      + 'finitions/common"},{"type":"object","properties":{"diameter":{"type":"'
      + 'number","minimum":0,"exclusiveMinimum":true,"description":"diameter in'
      + ' meters"},"height":{"type":"number","minimum":0,"exclusiveMinimum":tru'
      + 'e,"description":"height in meters"},"shape":{"type":"string","enum":["'
      + 'cylinder"],"description":"shape identifier"}},"description":"cylinder '
      + 'specific properties","required":["shape","diameter","height"]}],"descr'
      + 'iption":"cylinder"},"rectangle":{"type":"object","allOf":[{"$ref":"#/d'
      + 'efinitions/common"},{"type":"object","properties":{"width":{"type":"nu'
      + 'mber","minimum":0,"exclusiveMinimum":true,"description":"width in mete'
      + 'rs"},"length":{"type":"number","minimum":0,"exclusiveMinimum":true,"de'
      + 'scription":"length in meters"},"shape":{"type":"string","enum":["recta'
      + 'ngle"]}},"description":"rectangle specific properties","required":["sh'
      + 'ape","length","width"]}],"description":"rectangle"},"chevron":{"type":'
      + '"object","allOf":[{"$ref":"#/definitions/common"},{"type":"object","pr'
      + 'operties":{"outside_edge_length":{"type":"number","minimum":0,"exclusi'
      + 'veMinimum":true,"description":"length of the two outer edges in meters'
      + '"},"thickness":{"type":"number","minimum":0,"exclusiveMinimum":true,"d'
      + 'escription":"thickness in meters"},"shape":{"type":"string","enum":["c'
      + 'hevron"],"description":"shape identifier"}},"description":"chevron '
      + 'specific properties","required":["shape","outside_edge_length","thickn'
      + 'ess"]}],"description":"chevron"},"sphere":{"type":"object","allOf":[{"'
      + '$ref":"#/definitions/common"},{"type":"object","properties":{"diameter'
      + '":{"type":"number","minimum":0,"exclusiveMinimum":true,"description":"'
      + 'diameter in meters"},"shape":{"type":"string","enum":["sphere"],"descr'
      + 'iption":"shape identifier"}},"description":"sphere specific properties'
      + '","required":["shape","diameter"]}],"description":"sphere"},"common":{'
      + '"type":"object","properties":{"surface_type":{"type":"string","enum":['
      + '"retro_reflective_foil","diffuse"],"description":"surface material '
      + 'type"},"description":{"type":"string","description":"string describing'
      + ' the object"},"shape":{"type":"string","enum":["rectangle","checkerboa'
      + 'rd2x2","chevron","circular_disk","cylinder","sphere","round_corner_cub'
      + 'e_prism"],"description":"shape '
      + 'identifier"},"name":{"type":"string","description":"unique type '
      + 'identifier","minLength":3}},"description":"common object properties","'
      + 'required":["name","shape"]},"circular_disk":{"type":"object","allOf":['
      + '{"$ref":"#/definitions/common"},{"type":"object","properties":{"diamet'
      + 'er":{"type":"number","minimum":0,"exclusiveMinimum":true,"description"'
      + ':"diameter in meters"},"offset":{"type":"number","description":"offset'
      + ' in meters, e.g. reflector constant (optional)"},"shape":{"type":"stri'
      + 'ng","enum":["circular_disk"],"description":"shape '
      + 'identifier"}},"description":"circular disk specific '
      + 'properties","required":["shape","diameter"]}],"description":"circular '
      + 'disk"},"checkerboard2x2":{"type":"object","allOf":[{"$ref":"#/definiti'
      + 'ons/common"},{"type":"object","properties":{"square_length":{"type":"n'
      + 'umber","minimum":0,"exclusiveMinimum":true,"description":"length of a '
      + 'square of the checkerboard in meters"},"shape":{"type":"string","enum"'
      + ':["checkerboard2x2"],"description":"shape '
      + 'identifier"}},"description":"checkerboard specific properties","requir'
      + 'ed":["shape","square_length"]}],"description":"checkerboard 2 by 2"}}}'
    );

    Example : (''
      + '{"types":[{"width":0.3,"length":0.6,"description":"Rectangle (60cm x '
      + '30cm)","shape":"rectangle","name":"Rectangle '
      + '60x30"},{"width":0.4,"length":0.8,"description":"Rectangle (80cm x '
      + '40cm)","shape":"rectangle","name":"Rectangle '
      + '80x40"},{"square_length":0.3,"description":"Checkerboard (square '
      + 'length: 30cm)","shape":"checkerboard2x2","name":"Checkerboard2x2 '
      + '30"},{"square_length":0.5,"description":"Checkerboard (square length: '
      + '50cm)","shape":"checkerboard2x2","name":"Checkerboard2x2 50"},{"thickn'
      + 'ess":0.1016,"outside_edge_length":0.6096,"description":"Chevron '
      + '(a=24''''; b=4'''')","shape":"chevron","name":"Chevron '
      + '24''''/4''''"},{"diameter":0.5,"surface_type":"diffuse","description":" '
      + 'Circular Disk (diameter: '
      + '50cm)","shape":"circular_disk","name":"Circular Disk 50"},{"surface_ty'
      + 'pe":"retro_reflective_foil","offset":0.0,"shape":"circular_disk","diam'
      + 'eter":0.05,"name":"RIEGL flat reflector 50 mm","description":"flat '
      + 'circular reflector from retro-reflective foil"},{"surface_type":"retro'
      + '_reflective_foil","offset":0.0,"shape":"circular_disk","diameter":0.1,'
      + '"name":"RIEGL flat reflector 100 mm","description":"flat circular '
      + 'reflector from retro-reflective foil"},{"surface_type":"retro_reflecti'
      + 've_foil","offset":0.0,"shape":"circular_disk","diameter":0.15,"name":"'
      + 'RIEGL flat reflector 150 mm","description":"flat circular reflector '
      + 'from retro-reflective foil"},{"surface_type":"retro_reflective_foil","'
      + 'description":"cylindrical reflector from retro-reflective '
      + 'foil","height":0.05,"diameter":0.05,"shape":"cylinder","name":"RIEGL '
      + 'cylindrical reflector 50 mm"},{"surface_type":"retro_reflective_foil",'
      + '"description":"cylindrical reflector from retro-reflective '
      + 'foil","height":0.1,"diameter":0.1,"shape":"cylinder","name":"RIEGL '
      + 'cylindrical reflector 100 mm"},{"diameter":0.2,"description":"Sphere '
      + '(diameter: 200 mm)","shape":"sphere","name":"Sphere 200 '
      + 'mm"},{"diameter":0.05,"offset":0.0,"description":"round corner cube '
      + 'prism","shape":"round_corner_cube_prism","name":"Corner Cube Prism 50 '
      + 'mm"}],"comments":["This file contains a list of control object types '
      + '(aka. ''catalog'').","Each type is described by an object,","which must '
      + 'contain at least the following parameters:","  - name: unique '
      + 'identifier of the type","  - shape: one of the following supported '
      + 'shapes:","      - rectangle","      - checkerboard2x2","      - '
      + 'chevron","      - circular_disk","      - cylinder","      - sphere","'
      + '      - round_corner_cube_prism","Depending on ''shape'', the following '
      + 'parameters must/may be specified:","  - rectangle:","      - length: '
      + 'length in meters","      - width: width in meters","  - '
      + 'checkerboard2x2:","      - square_length: length of a square of the '
      + 'checkerboard in meters","  - circular_disk:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","  - chevron:","      - outside_edge_length: '
      + 'length of the two outer edges in meters","      - thickness: thickness'
      + ' in meters","  - cylinder:","      - diameter: diameter in meters","'
      + '      - height:  height in meters","  - sphere:","      - diameter: '
      + 'diameter in meters","  - round_corner_cube_prism:","      - diameter: '
      + 'diameter in meters","      - offset: offset in meters, e.g. reflector '
      + 'constant (optional)","Optional parameters:","    - description: string'
      + ' describing the object","    - surface_type: surface material type '
      + '(either ''retro_reflective_foil'' or ''diffuse'')"]}'
    );
  );

// Details about the control object reference file
const
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.control_object_reference_file';
    Title       : 'Control Object Reference file';
    Description : 'Details about the control object reference file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'description":"Details about the control object reference '
      + 'file","title":"Control Object Reference file","properties":{"reference'
      + '_file":{"type":"object","properties":{"file_path":{"type":"string","de'
      + 'scription":"Path of the control object file relative to referring '
      + 'file"},"file_uuid":{"type":"string","description":"Control object '
      + 'file''s Universally Unique Identifier (RFC '
      + '4122)"}},"description":"Reference to a control object '
      + 'file","required":["file_uuid","file_path"]}}}'
    );

    Example : (''
      + '{"reference_file":{"file_path":"../../../10_CONTROL_OBJECTS/ControlPoi'
      + 'nts.cpx","file_uuid":"810f5d57-eccf-49ed-b07a-0cdd109b4213"}}'
    );
  );

// Detection probability as a function of amplitude
const
  RDB_RIEGL_DETECTION_PROBABILITY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.detection_probability';
    Title       : 'Detection Probability';
    Description : 'Detection probability as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"detection_probability":{"type":"array","description":"'
      + 'Detection probability [0..1]","items":{"type":"number"}},"amplitude":{'
      + '"type":"array","description":"Amplitude '
      + '[dB]","items":{"type":"number"}}},"description":"Detection probability'
      + ' as a function of amplitude","title":"Detection Probability","required'
      + '":["amplitude","detection_probability"],"type":"object","$schema":"htt'
      + 'p://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"detection_probability":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]'
      + ',"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}'
    );
  );

// Details about the device used to acquire the point cloud
const
  RDB_RIEGL_DEVICE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device';
    Title       : 'Device Information';
    Description : 'Details about the device used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"device_name":{"type":"string","description":"Optional '
      + 'device name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)"},"channel_text":{"type":"string","description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel '
      + 'devices)"},"device_build":{"type":"string","description":"Device build'
      + ' variant"},"channel_number":{"type":"integer","minimum":0,"exclusiveMi'
      + 'nimum":false,"description":"Laser channel number (not defined or 0: '
      + 'single channel '
      + 'device)"},"device_type":{"type":"string","description":"Device type '
      + 'identifier (e.g. '
      + 'VZ-400i)"},"serial_number":{"type":"string","description":"Device '
      + 'serial number (e.g. S2221234)"}},"description":"Details about the '
      + 'device used to acquire the point cloud","title":"Device Information","'
      + 'required":["device_type","serial_number"],"type":"object","$schema":"h'
      + 'ttp://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"device_name":"Scanner 1","channel_text":"","device_build":"","channe'
      + 'l_number":0,"device_type":"VZ-400i","serial_number":"S2221234"}'
    );
  );

// Scanner device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry';
    Title       : 'Device Geometry';
    Description : 'Scanner device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"amu":{"type":"object","properties":{"frameCC":{"type":'
      + '"number","minimum":0,"exclusiveMinimum":false,"description":"Frame '
      + 'Circle Count (number of LSBs per full rotation about frame axis)"},"li'
      + 'neCC":{"type":"number","minimum":0,"exclusiveMinimum":false,"descripti'
      + 'on":"Line Circle Count (number of LSBs per full rotation about line '
      + 'axis)"}},"description":"Angle Measurement Unit"},"primary":{"type":"ob'
      + 'ject","properties":{"ID":{"type":"array","maxItems":2,"minItems":2,"de'
      + 'scription":"Structure identifier","items":{"type":"integer"}},"content'
      + '":{"type":"array","description":"Internal calibration '
      + 'values","items":{"type":"number"}}},"description":"Primary device '
      + 'geometry structure (mandatory)","required":["ID","content"]},"secondar'
      + 'y":{"type":"object","properties":{"ID":{"type":"array","maxItems":2,"m'
      + 'inItems":2,"description":"Structure identifier","items":{"type":"integ'
      + 'er"}},"content":{"type":"array","description":"Internal calibration '
      + 'values","items":{"type":"number"}}},"description":"Additional device '
      + 'geometry structure '
      + '(optional)","required":["ID","content"]}},"description":"Scanner '
      + 'device geometry details","title":"Device Geometry","required":["primar'
      + 'y"],"type":"object","$schema":"http://json-schema.org/draft-04/schema#'
      + '"}'
    );

    Example : (''
      + '{"amu":{"frameCC":124000,"lineCC":124000},"primary":{"ID":[4,0],"conte'
      + 'nt":[0]},"secondary":{"ID":[91,0],"content":[0]}}'
    );
  );

// Scanner passive channel device geometry details
const
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_geometry_passive_channel';
    Title       : 'Device Geometry Passive Channel';
    Description : 'Scanner passive channel device geometry details';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"primary":{"type":"object","properties":{"ID":{"type":"'
      + 'array","maxItems":2,"minItems":2,"description":"Structure identifier",'
      + '"items":{"type":"integer"}},"content":{"type":"array","description":"I'
      + 'nternal calibration '
      + 'values","items":{"type":"number"}}},"description":"Primary device '
      + 'geometry structure '
      + '(mandatory)","required":["ID","content"]}},"description":"Scanner '
      + 'passive channel device geometry details","title":"Device Geometry '
      + 'Passive Channel","required":["primary"],"type":"object","$schema":"htt'
      + 'p://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"primary":{"ID":[143,0],"content":[0]}}'
    );
  );

// Limits of the measured values output by the device
const
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.device_output_limits';
    Title       : 'Device Output Limits';
    Description : 'Limits of the measured values output by the device';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'description":"Limits of the measured values output by the device. The '
      + 'limits depend on the device type, measurement program and/or scan '
      + 'pattern.","title":"Device Output Limits","properties":{"reflectance_mi'
      + 'nimum":{"type":"number","description":"Minimum possible reflectance in'
      + ' dB."},"range_minimum":{"type":"number","description":"Minimum '
      + 'possible range in '
      + 'meters."},"deviation_minimum":{"type":"number","description":"Minimum '
      + 'possible pulse shape deviation."},"amplitude_minimum":{"type":"number"'
      + ',"description":"Minimum possible amplitude in dB."},"background_radiat'
      + 'ion_maximum":{"type":"number","description":"Maximum possible '
      + 'background radiation."},"reflectance_maximum":{"type":"number","descri'
      + 'ption":"Maximum possible reflectance in dB."},"background_radiation_mi'
      + 'nimum":{"type":"number","description":"Minimum possible background rad'
      + 'iation."},"mta_zone_count_maximum":{"type":"number","description":"Max'
      + 'imum number of MTA '
      + 'zones."},"range_maximum":{"type":"number","description":"Maximum '
      + 'possible range in '
      + 'meters."},"amplitude_maximum":{"type":"number","description":"Maximum '
      + 'possible amplitude in '
      + 'dB."},"echo_count_maximum":{"type":"number","description":"Maximum '
      + 'number of echoes a laser shot can '
      + 'have."},"deviation_maximum":{"type":"number","description":"Maximum '
      + 'possible pulse shape deviation."}}}'
    );

    Example : (''
      + '{"reflectance_minimum":-100.0,"range_minimum":2.9,"range_maximum":1000'
      + '0.0,"amplitude_minimum":0.0,"amplitude_maximum":100.0,"background_radi'
      + 'ation_maximum":0,"reflectance_maximum":100.0,"mta_zone_count_maximum":'
      + '7,"deviation_minimum":-1,"background_radiation_minimum":0,"deviation_m'
      + 'aximum":32767}'
    );
  );

// Details about the devices used to acquire the point cloud
const
  RDB_RIEGL_DEVICES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.devices';
    Title       : 'Devices Information';
    Description : 'Details about the devices used to acquire the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"array","$schema":"http://json-schema.org/draft-04/schema#","d'
      + 'escription":"Details about the devices used to acquire the point cloud'
      + ' (e.g. when merging point clouds of different '
      + 'devices)","title":"Devices Information","items":{"type":"object","prop'
      + 'erties":{"device_name":{"type":"string","description":"Optional device'
      + ' name (e.g. ''Scanner 1'' for multi-scanner '
      + 'systems)"},"signed":{"type":"boolean","description":"Flag that is set '
      + 'when the original ''riegl.device'' entry in the source file was '
      + 'correctly '
      + 'signed."},"channel_text":{"type":"string","description":"Optional '
      + 'channel description (e.g. ''Green Channel'' for multi-channel '
      + 'devices)"},"device_build":{"type":"string","description":"Device build'
      + ' variant"},"channel_number":{"type":"integer","minimum":0,"exclusiveMi'
      + 'nimum":false,"description":"Laser channel number (not defined or 0: '
      + 'single channel '
      + 'device)"},"device_type":{"type":"string","description":"Device type '
      + 'identifier (e.g. '
      + 'VZ-400i)"},"serial_number":{"type":"string","description":"Device '
      + 'serial number (e.g. '
      + 'S2221234)"}},"required":["device_type","serial_number"]}}'
    );

    Example : (''
      + '[{"device_name":"Scanner 1","signed":false,"channel_text":"","device_b'
      + 'uild":"","channel_number":0,"device_type":"VZ-400i","serial_number":"S'
      + '2221234"},{"device_name":"Scanner 2","signed":true,"channel_text":"","'
      + 'device_build":"","channel_number":1,"device_type":"VQ-1560i-DW","seria'
      + 'l_number":"S2222680"},{"device_name":"Scanner 3","signed":true,"channe'
      + 'l_text":"","device_build":"","channel_number":2,"device_type":"VQ-1560'
      + 'i-DW","serial_number":"S2222680"}]'
    );
  );

// Details about echo files
const
  RDB_RIEGL_ECHO_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.echo_info';
    Title       : 'Echo Information';
    Description : 'Details about echo files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"echo_file":{"type":"object","properties":{"file_extens'
      + 'ion":{"type":"string","description":"Echo file extension, without the '
      + 'leading dot"},"file_uuid":{"type":"string","description":"File''s '
      + 'Universally Unique Identifier (RFC '
      + '4122)"}},"required":["file_extension"]}},"description":"Details about '
      + 'echo files","title":"Echo Information","required":["echo_file"],"type"'
      + ':"object","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"echo_file":{"file_extension":"owp","file_uuid":"26a03615-67c0-4bea-8'
      + 'fe8-c577378fe661"}}'
    );
  );

// Details for exponential decomposition of full waveform data
const
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.exponential_decomposition';
    Title       : 'Exponential Decomposition';
    Description : 'Details for exponential decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"patternProperties":{"^[0-9]+$":{"description":"one field per '
      + 'channel, field name is channel '
      + 'index","$ref":"#/definitions/channel"}},"description":"Details for '
      + 'exponential decomposition of full waveform data","title":"Exponential '
      + 'Decomposition","additionalProperties":false,"type":"object","$schema":'
      + '"http://json-schema.org/draft-04/schema#","definitions":{"channel":{"t'
      + 'ype":"object","properties":{"a_lin":{"maximum":1,"description":"relati'
      + 've linear amplitude range [0..1]","type":"number","minimum":0,"exclusi'
      + 'veMinimum":false,"exclusiveMaximum":false},"parameter":{"type":"object'
      + '","properties":{"B":{"type":"array","description":"imaginary part of '
      + 'amplitude factor in units of full-scale","items":{"type":"number"}},"A'
      + '":{"type":"array","description":"real part of amplitude factor in '
      + 'units of full-scale","items":{"type":"number"}},"omega":{"type":"array'
      + '","description":"angular frequency in Hz","items":{"type":"number"}},"'
      + 'gamma":{"type":"array","description":"decay in '
      + '1/second","items":{"type":"number"}}},"description":"parameters of the'
      + ' syswave exponential sum","required":["A","B","gamma","omega"]},"scale'
      + '":{"type":"number","description":"amplitude '
      + 'calibration"},"delay":{"type":"number","description":"delay '
      + 'calibration in seconds"}},"required":["delay","scale","parameter"]}}}'
    );

    Example : (''
      + '{"1":{"a_lin":0.9,"parameter":{"B":[-3.9,0.0,-0.3],"A":[0.9,0.3,-1.3],'
      + '"omega":[352020896.0,3647927552.0,-1977987072.0],"gamma":[-1094726528.'
      + '0,-769562752.0,-848000064.0]},"scale":1.0,"delay":3.5e-09},"0":{"a_lin'
      + '":0.27,"parameter":{"B":[-3.9813032150268555,0.08622030913829803,-0.31'
      + '52860999107361],"A":[0.9772450923919678,0.3354335129261017,-1.31267857'
      + '5515747],"omega":[352020896.0,3647927552.0,-1977987072.0],"gamma":[-10'
      + '94726528.0,-769562752.0,-848000064.0]},"scale":1.0,"delay":3.783458418'
      + '887631e-09}}'
    );
  );

// Details for Gaussian decomposition of full waveform data
const
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.gaussian_decomposition';
    Title       : 'Gaussian Decomposition';
    Description : 'Details for Gaussian decomposition of full waveform data';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"range_offset_sec_low_power":{"type":"array","items":{"'
      + 'type":"number"}},"amplitude_lsb_high_power":{"type":"array","items":{"'
      + 'type":"number"}},"amplitude_lsb_low_power":{"type":"array","items":{"t'
      + 'ype":"number"}},"range_offset_sec_high_power":{"type":"array","items":'
      + '{"type":"number"}},"amplitude_db":{"type":"array","items":{"type":"num'
      + 'ber"}}},"description":"riegl.gaussian_decomposition contains '
      + 'information relevant for extracting calibrated amplitudes and '
      + 'calibrated ranges from a Gaussian decomposition of full waveform data.'
      + ' This information is contained in a table with five columns. Two '
      + 'columns are to be used as input: amplitude_lsb_low_power and '
      + 'amplitude_lsb_high_power. The other three columns provide the outputs.'
      + ' Amplitude_db gives the calibrated amplitude in the optical regime in '
      + 'decibels. The range offset columns provide additive range offsets, '
      + 'given in units of seconds, for each channel.","title":"Gaussian Decomp'
      + 'osition","required":["amplitude_lsb_low_power","amplitude_lsb_high_pow'
      + 'er","amplitude_db","range_offset_sec_low_power","range_offset_sec_high'
      + '_power"],"type":"object","$schema":"http://json-schema.org/draft-04/sc'
      + 'hema#"}'
    );

    Example : (''
      + '{"range_offset_sec_low_power":[],"amplitude_lsb_high_power":[],"amplit'
      + 'ude_lsb_low_power":[],"range_offset_sec_high_power":[],"amplitude_db":'
      + '[]}'
    );
  );

// Point cloud georeferencing information
const
  RDB_RIEGL_GEO_TAG : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geo_tag';
    Title       : 'Geo Tag';
    Description : 'Point cloud georeferencing information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'description":"Point cloud georeferencing information","title":"Geo Tag'
      + '","properties":{"crs":{"type":"object","properties":{"wkt":{"type":"st'
      + 'ring","description":"\"Well-Known Text\" string, OGC WKT dialect (see '
      + 'http://www.opengeospatial.org/standards/wkt-crs)"},"epsg":{"type":"int'
      + 'eger","minimum":0,"description":"EPSG '
      + 'code"},"name":{"type":"string","description":"Coordinate reference '
      + 'system name"}},"description":"Global Coordinate Reference System. '
      + 'Please note that only 3D Cartesian Coordinate Systems are allowed."},"'
      + 'pose":{"type":"array","maxItems":4,"minItems":4,"description":"Coordin'
      + 'ate Transformation Matrix to transform from File Coordinate System to '
      + 'Global Coordinate Reference System. 4x4 matrix stored as two '
      + 'dimensional array, row major order.","items":{"type":"array","maxItems'
      + '":4,"minItems":4,"description":"rows","items":{"type":"number","descri'
      + 'ption":"columns"}}}}}'
    );

    Example : (''
      + '{"crs":{"wkt":"GEOCCS[\"WGS84 Geocentric\",DATUM[\"WGS84\",SPHEROID[\"'
      + 'WGS84\",6378137.000,298.257223563,AUTHORITY[\"EPSG\",\"7030\"]],AUTHOR'
      + 'ITY[\"EPSG\",\"6326\"]],PRIMEM[\"Greenwich\",0.0000000000000000,AUTHOR'
      + 'ITY[\"EPSG\",\"8901\"]],UNIT[\"Meter\",1.00000000000000000000,AUTHORIT'
      + 'Y[\"EPSG\",\"9001\"]],AXIS[\"X\",OTHER],AXIS[\"Y\",EAST],AXIS[\"Z\",NO'
      + 'RTH],AUTHORITY[\"EPSG\",\"4978\"]]","epsg":4978,"name":"WGS84 Geocentr'
      + 'ic"},"pose":[[-0.269827776749716,-0.723017716139738,0.635954678449952,'
      + '4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847'
      + ',1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196'
      + '],[0.0,0.0,0.0,1.0]]}'
    );
  );

// Geometric scale factor applied to point coordinates
const
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.geometric_scale_factor';
    Title       : 'Geometric Scale Factor';
    Description : 'Geometric scale factor applied to point coordinates';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"number","minimum":0,"$schema":"http://json-schema.org/draft-0'
      + '4/schema#","exclusiveMinimum":true,"description":"Geometric scale '
      + 'factor applied to point coordinates"}'
    );

    Example : (''
      + '1.0'
    );
  );

// Parameters used for georeferencing of the point cloud
const
  RDB_RIEGL_GEOREFERENCING_PARAMETERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.georeferencing_parameters';
    Title       : 'Georeferencing Parameters';
    Description : 'Parameters used for georeferencing of the point cloud';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'description":"Parameters used for georeferencing of the point '
      + 'cloud","title":"Georeferencing Parameters","properties":{"trajectory_f'
      + 'ile":{"type":"object","properties":{"file_extension":{"type":"string",'
      + '"description":"Trajectory file extension, without the leading '
      + 'dot"},"file_uuid":{"type":"string","description":"File''s Universally '
      + 'Unique Identifier (RFC 4122)"}},"description":"Trajectory data used '
      + 'for georeferencing of the point cloud","required":["file_extension"]},'
      + '"body_coordinate_system_type":{"type":"string","enum":["NED","ENU"],"d'
      + 'escription":"BODY coordinate frame (NED: North-East-Down, ENU: '
      + 'East-North-Up), default: NED"},"socs_to_rocs_matrix":{"type":"array","'
      + 'maxItems":4,"minItems":4,"description":"Coordinate Transformation '
      + 'Matrix to transform from Scanner''s Own Coordinate System to Record '
      + 'Coordinate System. 4x4 matrix stored as two dimensional array, row '
      + 'major order.","items":{"type":"array","maxItems":4,"minItems":4,"descr'
      + 'iption":"rows","items":{"type":"number","description":"columns"}}},"so'
      + 'cs_to_body_matrix":{"type":"array","maxItems":4,"minItems":4,"descript'
      + 'ion":"Coordinate Transformation Matrix to transform from Scanner''s Own'
      + ' Coordinate System to Body Coordinate System. 4x4 matrix stored as two'
      + ' dimensional array, row major order.","items":{"type":"array","maxItem'
      + 's":4,"minItems":4,"description":"rows","items":{"type":"number","descr'
      + 'iption":"columns"}}},"trajectory_offsets":{"type":"object","properties'
      + '":{"offset_height":{"type":"number","description":"[m]"},"version":{"t'
      + 'ype":"integer","description":"Meaning of offset values and how to '
      + 'apply them; version 0: '
      + 'Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), '
      + 'version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch'
      + ')*Rx(offset_roll)"},"offset_east":{"type":"number","description":"[m]"'
      + '},"offset_north":{"type":"number","description":"[m]"},"offset_yaw":{"'
      + 'type":"number","description":"[deg]"},"offset_roll":{"type":"number","'
      + 'description":"[deg]"},"offset_time":{"type":"number","description":"[s'
      + ']"},"offset_pitch":{"type":"number","description":"[deg]"}},"descripti'
      + 'on":"Correction offsets applied to the trajectory data"}}}'
    );

    Example : (''
      + '{"trajectory_file":{"file_extension":"pofx","file_uuid":"93a03615-66c0'
      + '-4bea-8ff8-c577378fe660"},"body_coordinate_system_type":"NED","socs_to'
      + '_body_matrix":[[-0.269827776749716,-0.723017716139738,0.63595467844995'
      + '2,0.0],[0.962908599449764,-0.20260517250352,0.178208229833847,0.0],[0.'
      + '0,0.660451759194338,0.7508684796801,0.0],[0.0,0.0,0.0,1.0]],"trajector'
      + 'y_offsets":{"offset_height":-0.2,"version":0,"offset_east":0.15,"offse'
      + 't_north":0.07,"offset_yaw":-0.45,"offset_roll":0.03,"offset_time":18.0'
      + '07,"offset_pitch":0.01}}'
    );
  );

// Map of item names
const
  RDB_RIEGL_ITEM_NAMES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.item_names';
    Title       : 'Item Names';
    Description : 'Map of item names';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"patternProperties":{"^-?[0-9]+$":{"type":"string","description":"One'
      + ' field per item, field name is item id, field value is item '
      + 'name"}},"description":"Map of item names","title":"Item Names","type":'
      + '"object","$schema":"http://json-schema.org/draft-04/schema#","addition'
      + 'alProperties":false}'
    );

    Example : (''
      + '{"-1":"Name of item with id -1","1":"Name of item with id 1","2":"Name'
      + ' of item with id 2","47":"Name of item with id 47"}'
    );
  );

// License keys for software features
const
  RDB_RIEGL_LICENSES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.licenses';
    Title       : 'Software License Keys';
    Description : 'License keys for software features';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"patternProperties":{"^.*$":{"type":"array","minItems":1,"description'
      + '":"Each field of the object represents a feature and holds a list of '
      + 'license keys, where the field name is the feature '
      + 'name.","items":{"type":"string","description":"License key (example: '
      + '''46AE032A - 39882AC4 - 9EC0A184 - '
      + '6F163D73'')"}}},"description":"License keys for software '
      + 'features","title":"Software License Keys","type":"object","$schema":"h'
      + 'ttp://json-schema.org/draft-04/schema#","additionalProperties":false}'
    );

    Example : (''
      + '{"Full Waveform Analysis Topography":["0FD5FF07 - 011A1255 - 9F76CACA '
      + '- 8D2ED557"],"Full Waveform Analysis Topography with GPU '
      + 'support":["8AB44126 - 23B92250 - 16E2689F - 34EF7E7B"],"MTA '
      + 'resolution":["468E020A - 39A922E4 - B681A184 - '
      + '673E3D72"],"Georeferencing":["46AE032A - 39882AC4 - 9EC0A184 - '
      + '6F163D73"]}'
    );
  );

// Parameters for MTA processing
const
  RDB_RIEGL_MTA_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.mta_settings';
    Title       : 'MTA Settings';
    Description : 'Parameters for MTA processing';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'description":"Parameters for MTA processing","title":"MTA Settings","p'
      + 'roperties":{"zone_count":{"type":"integer","minimum":0,"maximum":255,"'
      + 'description":"Maximum number of MTA zones."},"modulation_depth":{"type'
      + '":"number","minimum":0,"description":"Depth of pulse position '
      + 'modulation in meter."},"zone_width":{"type":"number","minimum":0,"desc'
      + 'ription":"Width of a MTA zone in meter."}}}'
    );

    Example : (''
      + '{"zone_count":23,"modulation_depth":9.368514,"zone_width":149.896225}'
    );
  );

// Lookup table for range correction based on raw range
const
  RDB_RIEGL_NEAR_RANGE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.near_range_correction';
    Title       : 'Near Range Correction Table';
    Description : 'Lookup table for range correction based on raw range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"content":{"type":"array","maxItems":2000,"minItems":1,'
      + '"description":"Correction value [m] to be added to the raw range","ite'
      + 'ms":{"type":"number"}},"delta":{"type":"number","description":"Delta '
      + 'between table entries [m], first entry is at range = 0 '
      + 'm"}},"description":"Lookup table for range correction based on raw '
      + 'range","title":"Near Range Correction Table","required":["delta","cont'
      + 'ent"],"type":"object","$schema":"http://json-schema.org/draft-04/schem'
      + 'a#"}'
    );

    Example : (''
      + '{"content":[0.0],"delta":0.512}'
    );
  );

// Standard deviation for range and amplitude as a function of amplitude
const
  RDB_RIEGL_NOISE_ESTIMATES : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.noise_estimates';
    Title       : 'Noise Estimates';
    Description : 'Standard deviation for range and amplitude as a function of amplitude';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"amplitude":{"type":"array","description":"Amplitude [d'
      + 'B]","items":{"type":"number"}},"amplitude_sigma":{"type":"array","desc'
      + 'ription":"Sigma amplitude [dB]","items":{"type":"number"}},"range_sigm'
      + 'a":{"type":"array","description":"Sigma range '
      + '[m]","items":{"type":"number"}}},"description":"Standard deviation for'
      + ' range and amplitude as a function of amplitude","title":"Noise Estima'
      + 'tes","required":["amplitude","range_sigma","amplitude_sigma"],"type":"'
      + 'object","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"amplitude":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0],"amplitude'
      + '_sigma":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.432,0.39,0.3'
      + '54],"range_sigma":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.0'
      + '18,0.016,0.014]}'
    );
  );

// Notch filter parameters for window glass echoes
const
  RDB_RIEGL_NOTCH_FILTER : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.notch_filter';
    Title       : 'Notch Filter';
    Description : 'Notch filter parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"range_minimum":{"type":"number","description":"Minimum'
      + ' range [m]"},"range_maximum":{"type":"number","description":"Maximum '
      + 'range [m]"},"amplitude_maximum":{"type":"number","minimum":0,"descript'
      + 'ion":"Maximum amplitude [dB]"}},"description":"Notch filter parameters'
      + ' for window glass echoes","title":"Notch Filter","required":["range_mi'
      + 'nimum","range_maximum","amplitude_maximum"],"type":"object","$schema":'
      + '"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"range_minimum":-0.5,"range_maximum":0.2,"amplitude_maximum":18.0}'
    );
  );

// Details about the pixels contained in the file
const
  RDB_RIEGL_PIXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pixel_info';
    Title       : 'Pixel Information';
    Description : 'Details about the pixels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"size_llcs":{"description":"Size of pixels in a locally'
      + ' levelled cartesian coordinate system (xy). This is only used for '
      + 'pixels based on a map projection.","$ref":"#/definitions/pixel_size"},'
      + '"size":{"description":"Size of pixels in file coordinate '
      + 'system.","$ref":"#/definitions/pixel_size"}},"description":"Details '
      + 'about the pixels contained in the file","title":"Pixel Information","r'
      + 'equired":["size"],"type":"object","$schema":"http://json-schema.org/dr'
      + 'aft-04/schema#","definitions":{"pixel_size":{"type":"array","maxItems"'
      + ':2,"minItems":2,"description":"Size of '
      + 'pixels.","items":{"type":"number","minimum":0,"description":"Length of'
      + ' pixel edge [m]."}}}}'
    );

    Example : (''
      + '{"size_llcs":[0.5156575252891171,0.5130835356683303],"size":[0.5971642'
      + '834779395,0.5971642834779395]}'
    );
  );

// Details about the plane patch matching process
const
  RDB_RIEGL_PLANE_PATCH_MATCHING : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_matching';
    Title       : 'Plane Patch Matching';
    Description : 'Details about the plane patch matching process';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"plane_patch_file_two":{"description":"Reference to the'
      + ' plane patch file two","$ref":"#/definitions/file_reference"},"plane_p'
      + 'atch_file_one":{"description":"Reference to the plane patch file '
      + 'one","$ref":"#/definitions/file_reference"}},"description":"Details '
      + 'about the plane patch matching process","title":"Plane Patch Matching"'
      + ',"required":["plane_patch_file_one","plane_patch_file_two"],"type":"ob'
      + 'ject","$schema":"http://json-schema.org/draft-04/schema#","definitions'
      + '":{"file_reference":{"type":"object","properties":{"file_path":{"type"'
      + ':"string","description":"Path of the plane patch file relative to the '
      + 'match file"},"file_uuid":{"type":"string","description":"Plane patch '
      + 'file''s Universally Unique Identifier (RFC '
      + '4122)"}},"description":"Reference to a plane patch '
      + 'file","required":["file_uuid","file_path"]}}}'
    );

    Example : (''
      + '{"plane_patch_file_two":{"file_path":"project.ptch","file_uuid":"fa47d'
      + '509-a64e-49ce-8b14-ff3130fbefa9"},"plane_patch_file_one":{"file_path":'
      + '"Record009_Line001/191025_121410_Scanner_1.ptch","file_uuid":"810f5d57'
      + '-eccf-49ed-b07a-0cdd109b4213"}}'
    );
  );

// Statistics about plane patches found by plane patch extractor
const
  RDB_RIEGL_PLANE_PATCH_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_patch_statistics';
    Title       : 'Plane Patch Statistics';
    Description : 'Statistics about plane patches found by plane patch extractor';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'description":"Statistics about plane patches found by plane patch '
      + 'extractor","title":"Plane Patch Statistics","properties":{"total_area"'
      + ':{"type":"number","description":"sum of all plane patch areas [m\u00b2'
      + ']"},"total_horizontal_area":{"type":"number","description":"sum of all'
      + ' plane patch areas projected to horizontal plane [m\u00b2]"}}}'
    );

    Example : (''
      + '{"total_area":14007.965,"total_horizontal_area":13954.601}'
    );
  );

// Settings and classes for plane slope classification
const
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.plane_slope_class_info';
    Title       : 'Plane Slope Class Info';
    Description : 'Settings and classes for plane slope classification';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"classes":{"type":"object","patternProperties":{"^[0-9]'
      + '+$":{"type":"string","description":"one field per class, field name is'
      + ' class number, field value is class name"}},"description":"Class '
      + 'definition table","additionalProperties":false},"settings":{"type":"ob'
      + 'ject","oneOf":[{"$ref":"#/definitions/method-1"},{"$ref":"#/definition'
      + 's/method-2"}],"description":"Classification settings, details see '
      + 'documentation of rdbplanes"}},"description":"Settings and classes for '
      + 'plane slope classification","title":"Plane Slope Class Info","required'
      + '":["settings","classes"],"type":"object","$schema":"http://json-schema'
      + '.org/draft-04/schema#","definitions":{"method-2":{"type":"object","pro'
      + 'perties":{"sloping_plane_classes_maximum_angle":{"type":"number","mini'
      + 'mum":-360.0,"maximum":360.0,"description":"maximum inclination angle '
      + 'of sloping plane patches [deg]"},"sloping_plane_classes_minimum_angle"'
      + ':{"type":"number","minimum":-360.0,"maximum":360.0,"description":"mini'
      + 'mum inclination angle of sloping plane patches [deg]"},"plane_classifi'
      + 'cation_method":{"type":"integer","minimum":2,"maximum":2,"description"'
      + ':"method ID (=2)"}},"description":"Classification method 2","required"'
      + ':["plane_classification_method","sloping_plane_classes_minimum_angle",'
      + '"sloping_plane_classes_maximum_angle"]},"method-1":{"type":"object","p'
      + 'roperties":{"maximum_inclination_angle_horizontal":{"type":"number","m'
      + 'inimum":-360.0,"maximum":360.0,"description":"maximum inclination '
      + 'angle of horizontal plane patches [deg]"},"plane_classification_method'
      + '":{"type":"integer","minimum":1,"maximum":1,"description":"method ID '
      + '(=1)"}},"description":"Classification method 1","required":["plane_cla'
      + 'ssification_method","maximum_inclination_angle_horizontal"]}}}'
    );

    Example : (''
      + '{"classes":{"1":"horizontal, pointing up","14":"horizontal, pointing '
      + 'down","13":"sloping, pointing down and west","8":"vertical, pointing '
      + 'north","7":"vertical, pointing south","11":"sloping, pointing down and'
      + ' south","2":"sloping, pointing up and east","5":"sloping, pointing up '
      + 'and west","12":"sloping, pointing down and north","4":"sloping, '
      + 'pointing up and north","10":"sloping, pointing down and '
      + 'east","6":"vertical, pointing east","9":"vertical, pointing '
      + 'west","3":"sloping, pointing up and south"},"settings":{"sloping_plane'
      + '_classes_maximum_angle":70.0,"sloping_plane_classes_minimum_angle":10.'
      + '0,"plane_classification_method":2}}'
    );
  );

// Grouping and sorting of point attributes for visualization purposes
const
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.point_attribute_groups';
    Title       : 'Point Attribute Groups';
    Description : 'Grouping and sorting of point attributes for visualization purposes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"patternProperties":{"^.*$":{"type":"array","minItems":1,"description'
      + '":"Each field of the object represents a point attribute group and '
      + 'holds a list of point attributes, where the field name is the group '
      + 'name.","items":{"type":"string","description":"Point attribute full '
      + 'name or name pattern (perl regular expression '
      + 'syntax)"}}},"description":"Grouping and sorting of point attributes '
      + 'for visualization purposes","title":"Point Attribute Groups","type":"o'
      + 'bject","$schema":"http://json-schema.org/draft-04/schema#","additional'
      + 'Properties":false}'
    );

    Example : (''
      + '{"Other Attributes":["riegl.selected","riegl.visible"],"Secondary Attr'
      + 'ibutes":["riegl.mirror_facet","riegl.waveform_available"],"Time":["rie'
      + 'gl.timestamp"],"Coordinates/Vectors":["riegl.xyz","riegl.range","riegl'
      + '.theta","riegl.phi"],"Primary '
      + 'Attributes":["riegl.reflectance","riegl.amplitude","riegl.deviation"]}'
    );
  );

// Details about point cloud files
const
  RDB_RIEGL_POINTCLOUD_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pointcloud_info';
    Title       : 'Point Cloud Information';
    Description : 'Details about point cloud files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'description":"Details about point cloud files","title":"Point Cloud In'
      + 'formation","properties":{"project":{"type":"string","description":"Pro'
      + 'ject name"},"comments":{"type":"string","description":"Comments"},"fie'
      + 'ld_of_application":{"type":"string","enum":["unknown","SLS","TLS","KLS'
      + '","MLS","ULS","ALS","BLS","ILS"],"description":"Field of '
      + 'application"}}}'
    );

    Example : (''
      + '{"project":"Campaign 4","comments":"Line '
      + '3","field_of_application":"ALS"}'
    );
  );

// Estimated position and orientation information
const
  RDB_RIEGL_POSE_ESTIMATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_estimation';
    Title       : 'Pose Estimation';
    Description : 'Estimated position and orientation information';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"orientation":{"type":"object","properties":{"roll":{"t'
      + 'ype":"number","minimum":-360,"maximum":360,"description":"Roll angle '
      + 'about scanner X-axis [deg]"},"roll_accuracy":{"type":"number","minimum'
      + '":0,"exclusiveMinimum":true,"description":"Roll angle accuracy [deg]"}'
      + ',"pitch":{"type":"number","minimum":-360,"maximum":360,"description":"'
      + 'Pitch angle about scanner Y-axis [deg]"},"yaw_accuracy":{"type":"numbe'
      + 'r","minimum":0,"exclusiveMinimum":true,"description":"Yaw angle '
      + 'accuracy [deg]"},"yaw":{"type":"number","minimum":-360,"maximum":360,"'
      + 'description":"Yaw angle about scanner Z-axis [deg]"},"pitch_accuracy":'
      + '{"type":"number","minimum":0,"exclusiveMinimum":true,"description":"Pi'
      + 'tch angle accuracy [deg]"}},"description":"Orientation values and '
      + 'orientation accuracies, measured with IMU or inclination sensors.","re'
      + 'quired":["roll","pitch","yaw","roll_accuracy","pitch_accuracy","yaw_ac'
      + 'curacy"]},"position":{"type":"object","properties":{"coordinate_3":{"t'
      + 'ype":"number","description":"Coordinate 3 as defined by axis 3 of the '
      + 'specified CRS (e.g., Z, Altitude)"},"crs":{"type":"object","properties'
      + '":{"wkt":{"type":"string","description":"\"Well-Known Text\" string, '
      + 'OGC WKT dialect (see http://www.opengeospatial.org/standards/wkt-crs)"'
      + '},"epsg":{"type":"integer","minimum":0,"description":"EPSG '
      + 'code"}},"description":"Global Coordinate Reference System","required":'
      + '["epsg"]},"horizontal_accuracy":{"type":"number","minimum":0,"exclusiv'
      + 'eMinimum":true,"description":"Horizontal accuracy '
      + '[m]"},"coordinate_2":{"type":"number","description":"Coordinate 2 as '
      + 'defined by axis 2 of the specified CRS (e.g., Y, '
      + 'Longitude)"},"coordinate_1":{"type":"number","description":"Coordinate'
      + ' 1 as defined by axis 1 of the specified CRS (e.g., X, Latitude)"},"ve'
      + 'rtical_accuracy":{"type":"number","minimum":0,"exclusiveMinimum":true,'
      + '"description":"Vertical accuracy [m]"}},"description":"Position '
      + 'coordinates and position accuracy values as measured by GNSS in the '
      + 'specified Coordinate Reference System (CRS)","required":["coordinate_1'
      + '","coordinate_2","coordinate_3","horizontal_accuracy","vertical_accura'
      + 'cy","crs"]},"barometric_height_amsl":{"type":"number","description":"A'
      + 'ltitude determined based on the atmospheric pressure according to the '
      + 'standard atmosphere laws [m]."}},"description":"Estimated position and'
      + ' orientation information as measured by GNSS, IMU or inclination '
      + 'sensors","title":"Pose Estimation","required":["orientation"],"type":"'
      + 'object","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"orientation":{"roll":3.14743073066123,"roll_accuracy":0.009433783936'
      + '875745,"pitch":1.509153024827064,"yaw_accuracy":1.0094337839368757,"ya'
      + 'w":101.87293630292045,"pitch_accuracy":0.009433783936875745},"position'
      + '":{"coordinate_3":362.7124938964844,"crs":{"wkt":"GEOGCS[\"WGS84 / Geo'
      + 'graphic\",DATUM[\"WGS84\",SPHEROID[\"WGS84\",6378137.000,298.257223563'
      + ',AUTHORITY[\"EPSG\",\"7030\"]],AUTHORITY[\"EPSG\",\"6326\"]],PRIMEM[\"'
      + 'Greenwich\",0.0000000000000000,AUTHORITY[\"EPSG\",\"8901\"]],UNIT[\"De'
      + 'gree\",0.01745329251994329547,AUTHORITY[\"EPSG\",\"9102\"]],AXIS[\"Lat'
      + 'itude\",NORTH],AXIS[\"Longitude\",EAST],AUTHORITY[\"EPSG\",\"4979\"]]"'
      + ',"epsg":4979},"horizontal_accuracy":0.810699999332428,"coordinate_2":1'
      + '5.645033406,"coordinate_1":48.655799473,"vertical_accuracy":1.33149993'
      + '41964722},"barometric_height_amsl":386.7457796227932}'
    );
  );

// Details on position and orientation sensors
const
  RDB_RIEGL_POSE_SENSORS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pose_sensors';
    Title       : 'Pose Sensors';
    Description : 'Details on position and orientation sensors';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"gyroscope":{"type":"object","properties":{"relative_no'
      + 'nlinearity":{"description":"Relative nonlinearity, dimensionless","$re'
      + 'f":"#/definitions/vector"},"offset":{"description":"Value to be '
      + 'subtracted from raw measurement values","$ref":"#/definitions/vector"}'
      + ',"z_axis":{"description":"Sensitive Z axis of sensor at frame angle = '
      + '0","$ref":"#/definitions/vector"},"x_axis":{"description":"Sensitive X'
      + ' axis of sensor at frame angle = 0","$ref":"#/definitions/vector"},"un'
      + 'it":{"type":"number","minimum":0,"exclusiveMinimum":true,"description"'
      + ':"Unit of raw data and calibration values, 1 LSB in '
      + 'rad/s"},"y_axis":{"description":"Sensitive Y axis of sensor at frame '
      + 'angle = '
      + '0","$ref":"#/definitions/vector"},"origin":{"description":"Sensor '
      + 'origin in SOCS [m] at frame angle = '
      + '0","$ref":"#/definitions/vector"}},"description":"Gyroscope details","'
      + 'required":["unit","x_axis","y_axis","z_axis","offset","origin","relati'
      + 've_nonlinearity"]},"accelerometer":{"type":"object","properties":{"rel'
      + 'ative_nonlinearity":{"description":"Relative nonlinearity, dimensionle'
      + 'ss","$ref":"#/definitions/vector"},"offset":{"description":"Value to '
      + 'be subtracted from raw measurement values","$ref":"#/definitions/vecto'
      + 'r"},"z_axis":{"description":"Sensitive Z axis of sensor at frame angle'
      + ' = '
      + '0","$ref":"#/definitions/vector"},"x_axis":{"description":"Sensitive X'
      + ' axis of sensor at frame angle = 0","$ref":"#/definitions/vector"},"un'
      + 'it":{"type":"number","minimum":0,"exclusiveMinimum":true,"description"'
      + ':"Unit of raw data and calibration values, 1 LSB in 9.81 '
      + 'm/s\u00b2"},"y_axis":{"description":"Sensitive Y axis of sensor at '
      + 'frame angle = '
      + '0","$ref":"#/definitions/vector"},"origin":{"description":"Sensor '
      + 'origin in SOCS [m] at frame angle = '
      + '0","$ref":"#/definitions/vector"}},"description":"Accelerometer detail'
      + 's","required":["unit","x_axis","y_axis","z_axis","offset","origin","re'
      + 'lative_nonlinearity"]},"magnetic_field_sensor":{"type":"object","prope'
      + 'rties":{"relative_nonlinearity":{"description":"Relative nonlinearity,'
      + ' dimensionless","$ref":"#/definitions/vector"},"offset":{"description"'
      + ':"Value to be subtracted from raw measurement values","$ref":"#/defini'
      + 'tions/vector"},"z_axis":{"description":"Sensitive Z axis of sensor at '
      + 'frame angle = '
      + '0","$ref":"#/definitions/vector"},"fixed":{"description":"Distortion '
      + 'of magnetic field caused by non-rotating scanner part","$ref":"#/defin'
      + 'itions/vector"},"x_axis":{"description":"Sensitive X axis of sensor at'
      + ' frame angle = 0","$ref":"#/definitions/vector"},"unit":{"type":"numbe'
      + 'r","minimum":0,"exclusiveMinimum":true,"description":"Unit of raw data'
      + ' and calibration values, 1 LSB in '
      + 'nT"},"y_axis":{"description":"Sensitive Y axis of sensor at frame '
      + 'angle = 0","$ref":"#/definitions/vector"}},"description":"Magnetic '
      + 'Field Sensor details","required":["unit","x_axis","y_axis","z_axis","o'
      + 'ffset","fixed","relative_nonlinearity"]}},"description":"Details on '
      + 'position and orientation sensors","title":"Pose Sensors","required":["'
      + 'gyroscope","accelerometer","magnetic_field_sensor"],"type":"object","$'
      + 'schema":"http://json-schema.org/draft-04/schema#","definitions":{"vect'
      + 'or":{"type":"array","maxItems":3,"minItems":3,"items":{"type":"number"'
      + ',"description":"Index 0=X, 1=Y, 2=Z component"}}}}'
    );

    Example : (''
      + '{"gyroscope":{"relative_nonlinearity":[2.888176311444113e-07,1.0627416'
      + '4579645e-07,-1.7186295080634935e-39],"offset":[-50.92609786987305,146.'
      + '15643310546875,62.4327278137207],"z_axis":[0.555869996547699,119.22135'
      + '162353516,0.467585027217865],"x_axis":[-121.195556640625,0.82197141647'
      + '33887,0.2313031703233719],"unit":0.00014544410805683583,"y_axis":[-0.4'
      + '40765917301178,-0.7897399663925171,119.5894775390625],"origin":[0.0269'
      + '00000870227814,-0.03999999910593033,-0.08950000256299973]},"accelerome'
      + 'ter":{"relative_nonlinearity":[0.0,0.0,0.0],"offset":[-733.36364746093'
      + '75,58.969032287597656,1060.2550048828125],"z_axis":[1.639882206916809,'
      + '15166.744140625,-116.99742889404297],"x_axis":[-15008.123046875,56.956'
      + '390380859375,-60.5175666809082],"unit":6.666666740784422e-05,"y_axis":'
      + '[-7.027288913726807,-44.12333679199219,14952.3701171875],"origin":[0.0'
      + '26900000870227814,-0.03999999910593033,-0.08950000256299973]},"magneti'
      + 'c_field_sensor":{"relative_nonlinearity":[0.0,0.0,0.0],"offset":[-2381'
      + '2.052734375,5606.57666015625,2493.28125],"z_axis":[0.00041987866279669'
      + '106,7.876977906562388e-05,0.011407104320824146],"fixed":[-1576.0104980'
      + '46875,1596.081787109375,0.0],"x_axis":[-0.011162743903696537,-2.315962'
      + '774446234e-05,0.00016818844596855342],"unit":91.74311828613281,"y_axis'
      + '":[0.00027888521435670555,-0.011427424848079681,-5.204829722060822e-05'
      + ']}}'
    );
  );

// Laser pulse position modulation used for MTA resolution
const
  RDB_RIEGL_PULSE_POSITION_MODULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.pulse_position_modulation';
    Title       : 'Pulse Position Modulation';
    Description : 'Laser pulse position modulation used for MTA resolution';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"num_mod_ampl":{"type":"integer","minimum":0,"maximum":'
      + '255,"description":"Number of different modulation amplitudes (2: '
      + 'binary modulation)"},"length":{"type":"integer","minimum":0,"maximum":'
      + '255,"description":"Length of code"},"code_phase_mode":{"type":"integer'
      + '","minimum":0,"maximum":255,"description":"0: no synchronization, 1: '
      + 'toggle between 2 phases, 2: increment with phase_increment"},"pulse_in'
      + 'terval":{"type":"array","description":"Explicit table of the pulse '
      + 'position modulation used for MTA resolution. Table gives times between'
      + ' successive laser pulses in seconds.","items":{"type":"number","minimu'
      + 'm":0}},"phase_step":{"type":"integer","minimum":0,"maximum":255,"descr'
      + 'iption":"Step width in phase of modulation code from line to '
      + 'line"}},"description":"Laser pulse position modulation used for MTA '
      + 'resolution","title":"Pulse Position Modulation","required":["length","'
      + 'num_mod_ampl","pulse_interval"],"type":"object","$schema":"http://json'
      + '-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"num_mod_ampl":2,"length":31,"code_phase_mode":2,"pulse_interval":[2.'
      + '759375e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.75937'
      + '5e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06'
      + ',2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.82'
      + '1875e-06,2.821875e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e'
      + '-06,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2'
      + '.759375e-06,2.821875e-06,2.759375e-06,2.821875e-06],"phase_step":5}'
    );
  );

// Statistics about target distance wrt. SOCS origin
const
  RDB_RIEGL_RANGE_STATISTICS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.range_statistics';
    Title       : 'Range Statistics';
    Description : 'Statistics about target distance wrt. SOCS origin';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"average":{"type":"number","description":"Average '
      + 'value"},"minimum":{"type":"number","description":"Minimum '
      + 'value"},"maximum":{"type":"number","description":"Maximum '
      + 'value"},"std_dev":{"type":"number","description":"Standard '
      + 'deviation"}},"description":"Statistics about target distance wrt. SOCS'
      + ' origin","title":"Range Statistics","required":["minimum","average","m'
      + 'aximum","std_dev"],"type":"object","$schema":"http://json-schema.org/d'
      + 'raft-04/schema#"}'
    );

    Example : (''
      + '{"average":15.49738,"minimum":0.919,"maximum":574.35,"std_dev":24.349}'
    );
  );

// Receiver Internals
const
  RDB_RIEGL_RECEIVER_INTERNALS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.receiver_internals';
    Title       : 'Receiver Internals';
    Description : 'Receiver Internals';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"nt":{"type":"integer","minimum":0,"maximum":255,"descr'
      + 'iption":"Number of '
      + 'traces"},"tbl":{"type":"array","minItems":1,"description":"various '
      + 'internal data","items":{"$ref":"#/definitions/fp_table"}},"mw":{"type"'
      + ':"number","minimum":0,"maximum":4095,"exclusiveMinimum":true,"descript'
      + 'ion":"Maximum weight"},"t":{"type":"object","patternProperties":{"^[0-'
      + '9]+$":{"description":"one field per channel, field name is channel ind'
      + 'ex","$ref":"#/definitions/fp"}},"additionalProperties":false},"sr":{"t'
      + 'ype":"number","minimum":0,"exclusiveMinimum":true,"description":"Sampl'
      + 'e rate [Hz]"},"si":{"type":"number","minimum":0,"maximum":255,"descrip'
      + 'tion":"Start index (hw_start)"},"ns":{"type":"integer","minimum":0,"ma'
      + 'ximum":4095,"description":"Number of samples"},"a":{"type":"array","ma'
      + 'xItems":256,"minItems":1,"description":"Amplitude [dB]","items":{"type'
      + '":"number"}},"ex":{"type":"object","description":"DEPRECATED, use '
      + '''riegl.exponential_decomposition'' instead"}},"description":"Receiver '
      + 'Internals","title":"Receiver Internals","type":"object","$schema":"htt'
      + 'p://json-schema.org/draft-04/schema#","definitions":{"fp_table_row":{"'
      + 'type":"array","maxItems":2048,"minItems":1,"items":{"type":"number"}},'
      + '"fp":{"type":"object","properties":{"w":{"type":"array","maxItems":256'
      + ',"minItems":1,"items":{"type":"array","maxItems":5,"minItems":5,"items'
      + '":{"type":"number"}}},"s":{"type":"array","maxItems":256,"minItems":1,'
      + '"items":{"type":"array","maxItems":4096,"minItems":1,"items":{"type":"'
      + 'number"}}}},"description":"Fingerprint values","required":["s","w"]},"'
      + 'fp_table":{"type":"object","desription":"scanner internal data","prope'
      + 'rties":{"tv":{"type":"array","maxItems":2048,"minItems":1,"items":{"on'
      + 'eOf":[{"$ref":"#/definitions/fp_table_row"},{"type":"number"}]}},"tc":'
      + '{"type":"integer","min":0,"description":"table data type '
      + 'code","max":255},"ny":{"type":"integer","min":1,"description":"number '
      + 'of y entries","max":2048},"ch":{"type":"integer","min":0,"description"'
      + ':"channel number","max":255},"nx":{"type":"integer","min":1,"descripti'
      + 'on":"number of x '
      + 'entries","max":2048}},"required":["ch","tc","nx","ny","tv"]}}}'
    );

    Example : (''
      + '{"nt":128,"mw":31,"t":{"1":{"w":[[78,86,126,134,31],[78,86,126,134,31]'
      + '],"s":[[1.23,4.56],[7.89,0.12]]},"0":{"w":[[78,86,126,134,31],[78,86,1'
      + '26,134,31]],"s":[[1.23,4.56],[7.89,0.12]]}},"sr":7959997000.0,"si":48,'
      + '"ns":400,"a":[-1.55],"tbl":[{"tv":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]],'
      + '"tc":1,"ny":2,"ch":0,"nx":5}]}'
    );
  );

// Lookup table for reflectance calculation based on amplitude and range
const
  RDB_RIEGL_REFLECTANCE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_calculation';
    Title       : 'Reflectance Calculation Table';
    Description : 'Lookup table for reflectance calculation based on amplitude and range';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"content":{"type":"array","maxItems":2000,"minItems":1,'
      + '"description":"Correction value [dB] to be added to the amplitude","it'
      + 'ems":{"type":"number"}},"delta":{"type":"number","description":"Delta '
      + 'between table entries [m], first entry is at range = 0 '
      + 'm"}},"description":"Lookup table for reflectance calculation based on '
      + 'amplitude and range","title":"Reflectance Calculation Table","required'
      + '":["delta","content"],"type":"object","$schema":"http://json-schema.or'
      + 'g/draft-04/schema#"}'
    );

    Example : (''
      + '{"content":[-33.01],"delta":0.150918}'
    );
  );

// Range-dependent and scan-angle-dependent correction of reflectance reading
const
  RDB_RIEGL_REFLECTANCE_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.reflectance_correction';
    Title       : 'Near-Range Reflectance Correction';
    Description : 'Range-dependent and scan-angle-dependent correction of reflectance reading';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"reflectance_correction_db":{"type":"array","descriptio'
      + 'n":"Near range reflectance correction in dB as a function of range '
      + 'over angle","items":{"type":"array","description":"rows (each array '
      + 'corresponds to a '
      + 'range)","items":{"type":"number","description":"columns (each value '
      + 'corresponds to an '
      + 'angle)"}}},"ranges_m":{"type":"array","description":"Range [m]","items'
      + '":{"type":"number"}},"line_angles_deg":{"type":"array","description":"'
      + 'Angle '
      + '[deg]","items":{"type":"number"}}},"description":"Range-dependent and '
      + 'scan-angle-dependent correction of reflectance '
      + 'reading","title":"Near-range reflectance correction","required":["rang'
      + 'es_m","line_angles_deg","reflectance_correction_db"],"type":"object","'
      + '$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"reflectance_correction_db":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.'
      + '01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0'
      + '.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],"ra'
      + 'nges_m":[0.0,1.0,2.0,3.0],"line_angles_deg":[0.0,0.5,1.0,1.5,1.0,2.0,2'
      + '.5,3.0,3.5,4.0]}'
    );
  );

// Scan pattern description
const
  RDB_RIEGL_SCAN_PATTERN : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.scan_pattern';
    Title       : 'Scan Pattern';
    Description : 'Scan pattern description';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"rectangular":{"type":"object","properties":{"phi_incre'
      + 'ment":{"type":"number","minimum":0.0,"maximum":90.0,"description":"Inc'
      + 'rement of phi angle in SOCS [deg]"},"phi_start":{"type":"number","mini'
      + 'mum":0.0,"maximum":360.0,"description":"Start phi angle in SOCS [deg]"'
      + '},"phi_stop":{"type":"number","minimum":0.0,"maximum":720.0,"descripti'
      + 'on":"Stop phi angle in SOCS [deg]"},"theta_start":{"type":"number","mi'
      + 'nimum":0.0,"maximum":180.0,"description":"Start theta angle in SOCS [d'
      + 'eg]"},"theta_increment":{"type":"number","minimum":0.0,"maximum":90.0,'
      + '"description":"Increment of theta angle in SOCS [deg]"},"program":{"$r'
      + 'ef":"#/definitions/program"},"theta_stop":{"type":"number","minimum":0'
      + '.0,"maximum":180.0,"description":"Stop theta angle in SOCS '
      + '[deg]"}},"description":"Rectangular Field Of View Scan Pattern","requi'
      + 'red":["phi_start","phi_stop","phi_increment","theta_start","theta_stop'
      + '","theta_increment"]},"segments":{"type":"object","properties":{"list"'
      + ':{"type":"array","items":{"type":"object","properties":{"stop":{"type"'
      + ':"number","minimum":0.0,"maximum":720.0,"description":"Stop angle in '
      + 'SOCS [deg]"},"start":{"type":"number","minimum":0.0,"maximum":360.0,"d'
      + 'escription":"Start angle in SOCS [deg]"},"increment":{"type":"number",'
      + '"minimum":0.0,"maximum":90.0,"description":"Increment of angle in SOCS'
      + ' [deg]"}},"description":"Line Scan Segment","required":["start","stop"'
      + ',"increment"]}},"program":{"$ref":"#/definitions/program"}},"descripti'
      + 'on":"Segmented Line Scan Pattern","required":["list"]},"line":{"type":'
      + '"object","properties":{"stop":{"type":"number","minimum":0.0,"maximum"'
      + ':720.0,"description":"Stop angle in SOCS [deg]"},"start":{"type":"numb'
      + 'er","minimum":0.0,"maximum":360.0,"description":"Start angle in SOCS ['
      + 'deg]"},"increment":{"type":"number","minimum":0.0,"maximum":90.0,"desc'
      + 'ription":"Increment of angle in SOCS [deg]"},"program":{"$ref":"#/defi'
      + 'nitions/program"}},"description":"Line Scan Pattern","required":["star'
      + 't","stop","increment"]}},"$schema":"http://json-schema.org/draft-04/sc'
      + 'hema#","description":"Scan pattern description","title":"Scan Pattern"'
      + ',"definitions":{"program":{"type":"object","properties":{"laser_prr":{'
      + '"type":"number","minimum":0,"exclusiveMinimum":false,"description":"La'
      + 'ser Pulse Repetition Rate '
      + '[Hz]"},"name":{"type":"string","description":"Name of measurement '
      + 'program"}},"description":"Measurement program","required":["name"]}}}'
    );

    Example : (''
      + '{"rectangular":{"phi_increment":0.04,"phi_start":45.0,"phi_stop":270.0'
      + ',"theta_start":30.0,"theta_increment":0.04,"program":{"laser_prr":1000'
      + '00.0,"name":"High Speed"},"theta_stop":130.0}}'
    );
  );

// Details about laser shot files
const
  RDB_RIEGL_SHOT_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.shot_info';
    Title       : 'Shot Information';
    Description : 'Details about laser shot files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'description":"Details about laser shot files","title":"Shot Informatio'
      + 'n","properties":{"shot_file":{"type":"object","properties":{"file_exte'
      + 'nsion":{"type":"string","description":"Shot file extension, without '
      + 'the leading dot"},"file_uuid":{"type":"string","description":"File''s '
      + 'Universally Unique Identifier (RFC '
      + '4122)"}},"required":["file_extension"]}}}'
    );

    Example : (''
      + '{"shot_file":{"file_extension":"sodx","file_uuid":"26a00815-67c0-4bff-'
      + '8fe8-c577378fe663"}}'
    );
  );

// Point filters applied in addition to the application-defined filters
const
  RDB_RIEGL_STORED_FILTERS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.stored_filters';
    Title       : 'Stored Filters';
    Description : 'Point filters applied in addition to the application-defined filters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"activated":{"type":"boolean","description":"Apply '
      + '(''true'') or ignore (''false'') all '
      + 'filters"},"filters":{"type":"array","description":"List of point filte'
      + 'rs","items":{"type":"object","properties":{"filter":{"type":"string","'
      + 'description":"The RDB filter string to apply (e.g. when reading points'
      + ' or index), details see documentation of function '
      + 'select()"},"title":{"type":"string","description":"A short filter '
      + 'title (e.g. for display in a selection '
      + 'list)"},"activated":{"type":"boolean","description":"Apply (''true'') or'
      + ' ignore (''false'') this '
      + 'filter"},"description":{"type":"string","description":"A brief '
      + 'description of the filter (e.g. for display in a '
      + 'tooltip)"}},"description":"Point filter definition","required":["activ'
      + 'ated","title","description","filter"]}}},"description":"Point filters '
      + 'applied in addition to the application-defined '
      + 'filters","title":"Stored filters","required":["activated","filters"],"'
      + 'type":"object","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"activated":true,"filters":[{"filter":"riegl.mta_uncertain_point == '
      + '0","title":"Ignore uncertain points from MTA '
      + 'resolution","activated":false,"description":"Ignore points with '
      + 'uncertain MTA zone '
      + 'assignment"},{"filter":"riegl.dyntrig_uncertain_point == '
      + '0","title":"Ignore points below dynamic trigger '
      + 'level","activated":false,"description":"Ignore points with an echo '
      + 'signal amplitude below the dynamic '
      + 'trigger"},{"filter":"riegl.point_outside_aabb_bocs == '
      + '0","title":"Ignore points outside outer '
      + 'AABB","activated":false,"description":"Ignore points that are outside '
      + 'the outer AABB in BOCS"},{"filter":"riegl.point_inside_aabb_bocs == '
      + '0","title":"Ignore points inside inner '
      + 'AABB","activated":false,"description":"Ignore points that are inside '
      + 'the inner AABB in BOCS"}]}'
    );
  );

// Details of major system components like lidar sensors, cameras and navigation devices
const
  RDB_RIEGL_SYSTEM_DESCRIPTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.system_description';
    Title       : 'System Description';
    Description : 'Details of major system components like lidar sensors, cameras and navigation devices';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"version":{"type":"string","description":"Document '
      + 'format version"},"author":{"type":"string","description":"Name of the '
      + 'author that created the '
      + 'document"},"system":{"type":"object","description":"The actual system '
      + 'description, details see documentation of RIEGL System '
      + 'Description"},"timestamp":{"type":"string","description":"Date and '
      + 'time of creation (e.g. 2019-06-19T13:32:10+02:00)"},"$class":{"type":"'
      + 'string","enum":["Document"],"description":"Object class '
      + 'name"}},"description":"Details of major system components like lidar '
      + 'sensors, cameras and navigation devices","title":"System Description",'
      + '"required":["$class","version","author","timestamp","system"],"type":"'
      + 'object","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"version":"1.2.1","author":"RIEGL LMS GmbH, '
      + 'Austria","system":{"details":"see documentation of RIEGL System Descri'
      + 'ption"},"timestamp":"2022-09-30T11:56:26+00:00","$class":"Document"}'
    );
  );

// Conversion of background radiation raw values to temperatures in °C
const
  RDB_RIEGL_TEMPERATURE_CALCULATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.temperature_calculation';
    Title       : 'Temperature Calculation Table';
    Description : 'Conversion of background radiation raw values to temperatures in °C';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"InGaAs":{"description":"Conversion table for InGaAs ch'
      + 'annel","$ref":"#/definitions/conversion_table"},"InGaAs_Si_Difference"'
      + ':{"description":"Conversion table for InGaAs - Si difference","$ref":"'
      + '#/definitions/conversion_table"},"Si":{"description":"Conversion table'
      + ' for Si channel","$ref":"#/definitions/conversion_table"}},"descriptio'
      + 'n":"Conversion of background radiation raw values to temperatures in '
      + '\u00b0C","title":"Temperature Calculation Table","type":"object","$sch'
      + 'ema":"http://json-schema.org/draft-04/schema#","definitions":{"convers'
      + 'ion_table":{"type":"object","properties":{"value":{"type":"array","des'
      + 'cription":"LSB [1]","items":{"type":"number"}},"temperature":{"type":"'
      + 'array","description":"Temperature [\u00b0C]","items":{"type":"number"}'
      + '}},"required":["value","temperature"]}}}'
    );

    Example : (''
      + '{"InGaAs":{"value":[0.0,64.00097659230323,128.0019531846065,192.002929'
      + '7769097,256.0039063692129,320.00488296151616,384.0058595538194,448.006'
      + '8361461226,512.0078127384259],"temperature":[307.22196722535614,309.11'
      + '53478247277,311.1188086915047,313.10025350480055,315.2137946389828,317'
      + '.2172555057597,319.2207163725366,321.2021611858325,323.3157023200148]}'
      + ',"InGaAs_Si_Difference":{"value":[1000.0,1100.090029602954,1200.044251'
      + '83874,1300.1342814416948,1400.0885036774805,1500.0427259132668,1600.13'
      + '27555162209,1700.0869777520065,1800.0411999877924],"temperature":[1749'
      + '.977111117893,1749.977111117893,1749.977111117893,1749.977111117893,17'
      + '49.977111117893,1749.977111117893,1744.7813348796044,1681.997131260109'
      + '2,1622.3944822534868]},"Si":{"value":[0.0,64.00097659230323,128.001953'
      + '1846065,192.0029297769097,256.0039063692129,320.00488296151616,384.005'
      + '8595538194,448.0068361461226,512.0078127384259],"temperature":[546.300'
      + '048828125,548.8164051212026,551.3143938500972,554.0144257850053,556.60'
      + '4252334815,559.2124464488079,561.8022729986177,564.4104671126105,567.0'
      + '002936624203]}}'
    );
  );

// Base of timestamps (epoch)
const
  RDB_RIEGL_TIME_BASE : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.time_base';
    Title       : 'Time Base';
    Description : 'Base of timestamps (epoch)';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"source":{"type":"string","enum":["unknown","RTC","GNSS'
      + '"],"description":"Timestamp '
      + 'source"},"epoch":{"type":"string","description":"Date and time of '
      + 'timestamp ''0'' as proposed by RFC 3339 (e.g. 2015-10-27T00:00:00+01:00)'
      + '."},"system":{"type":"string","enum":["unknown","UTC","GPS"],"descript'
      + 'ion":"Time system (time standard)"}},"description":"Base of timestamps'
      + ' (epoch)","title":"Time Base","required":["epoch","source"],"type":"ob'
      + 'ject","$schema":"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"source":"GNSS","epoch":"2015-10-27T00:00:00+00:00","system":"UTC"}'
    );
  );

// Details about position+orientation files
const
  RDB_RIEGL_TRAJECTORY_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.trajectory_info';
    Title       : 'Trajectory Information';
    Description : 'Details about position+orientation files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"navigation_frame":{"type":"string","enum":["unknown","'
      + 'NED","ENU"],"description":"Navigation frame (NED: North-East-Down, '
      + 'ENU: East-North-Up)"},"time_interval":{"type":"object","properties":{"'
      + 'average":{"type":"number","description":"Average time interval '
      + '[s]"},"minimum":{"type":"number","description":"Minimum time interval '
      + '[s]"},"maximum":{"type":"number","description":"Maximum time interval '
      + '[s]"},"std_dev":{"type":"number","description":"Standard deviation of '
      + 'intervals [s]"}},"description":"Time interval statistics","required":['
      + '"minimum","average","maximum","std_dev"]},"location":{"type":"string",'
      + '"description":"Project location, e.g. city/state/country"},"device":{"'
      + 'type":"string","description":"Navigation device, e.g. name/type/serial'
      + '"},"field_of_application":{"type":"string","enum":["unknown","SLS","TL'
      + 'S","KLS","MLS","ULS","ALS","BLS","ILS"],"description":"Field of '
      + 'application"},"project":{"type":"string","description":"Project '
      + 'name"},"company":{"type":"string","description":"Company '
      + 'name"},"software":{"type":"string","description":"Software that '
      + 'calculated the trajectory (this may be the same or different software '
      + 'than the one that created the '
      + 'file)"},"settings":{"type":"string","description":"Settings used to '
      + 'calculate the trajectory (descriptive text)"}},"description":"Details '
      + 'about position+orientation files","title":"Trajectory Information","re'
      + 'quired":["time_interval","navigation_frame"],"type":"object","$schema"'
      + ':"http://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"navigation_frame":"NED","time_interval":{"average":0.00500053,"minim'
      + 'um":0.00500032,"maximum":0.005004883,"std_dev":5.51e-07},"location":"H'
      + 'orn","device":"IMU Model 12/1, Serial# '
      + '12345","field_of_application":"MLS","project":"Campaign '
      + '3","company":"RIEGL LMS","software":"Navigation Software '
      + 'XYZ","settings":"default"}'
    );
  );

// Trigger-Timestamping-Unit/IP configuration
const
  RDB_RIEGL_TTIP_CONFIGURATION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.ttip_configuration';
    Title       : 'TTIP Configuration';
    Description : 'Trigger-Timestamping-Unit/IP configuration';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"in_polarity":{"type":"integer","minimum":0,"descriptio'
      + 'n":"0 .. positive edge, 1 .. negative '
      + 'edge"},"dmi_incr":{"type":"integer","description":"dmi, increment in '
      + 'ticks"},"dmi_dist_per_tick":{"type":"number","description":"dmi, '
      + 'distance per tick, just informative '
      + '[m]"},"ext_channel":{"type":"integer","minimum":0,"description":"ID of'
      + ' channel used as external trigger input, 32 indicates none"},"out_dura'
      + 'tion":{"type":"integer","minimum":0,"description":"output pulse '
      + 'duration  [0.1 msec]"},"in_max_delay":{"type":"integer","minimum":0,"d'
      + 'escription":"maximum delay to output pulse before fake event is '
      + 'generated [0.1 msec], zero indicates that no fake events are generated'
      + '"},"ext_subdivider":{"type":"integer","minimum":0,"description":"reduc'
      + 'es the frequency, default '
      + '1"},"out_interval":{"type":"integer","minimum":0,"description":"output'
      + ' pulse interval  [0.1 '
      + 'msec]"},"ext_signal":{"type":"integer","minimum":0,"description":"0 ..'
      + ' use input signal, 1 .. use output signal of channel"},"in_min_duratio'
      + 'n":{"type":"integer","minimum":0,"description":"input signals with '
      + 'smaller pulse durations are ignored [0.1 msec]"},"out_delay":{"type":"'
      + 'integer","minimum":0,"description":"output pulse initial delay after '
      + 'start  [0.1 msec]"},"dmi_max_time":{"type":"integer","minimum":0,"desc'
      + 'ription":"dmi, maximum time interval between trigger events [0.1 msec]'
      + '"},"ttip_version":{"type":"integer","minimum":0,"description":"followi'
      + 'ng main.sub.ss.sss"},"in_max_duration":{"type":"integer","minimum":0,"'
      + 'description":"stops measurement of pulse duration of input signal [0.1'
      + ' msec]"},"input_usage":{"type":"integer","minimum":0,"description":"0 '
      + '.. deactivated, 1 .. just detecting and timestamping"},"dmi_min_time":'
      + '{"type":"integer","minimum":0,"description":"dmi, minimum time '
      + 'interval between trigger events [0.1 msec]"},"ext_bitmask":{"type":"in'
      + 'teger","minimum":0,"description":"defines which of the internal pulse '
      + 'generators are to be started"},"num_channel":{"type":"integer","minimu'
      + 'm":0,"description":"number of input/output channels"},"out_polarity":{'
      + '"type":"integer","minimum":0,"description":"0 .. positive edge, 1 .. '
      + 'negative '
      + 'edge"},"output_usage":{"type":"integer","minimum":0,"description":"0 '
      + '.. no output, 1 .. output derived from internal clock, 2 .. output '
      + 'derived from dmi, 3 .. output derived from external signal, 4 .. '
      + 'output static low, 5 .. output static '
      + 'high"},"input_descr":{"type":"string","description":"descriptive strin'
      + 'g"},"ext_delay":{"type":"integer","minimum":0,"description":"external '
      + 'trigger, time delay [0.1 '
      + 'msec]"},"channel":{"type":"integer","minimum":0,"description":"ID of '
      + 'input/output channel"},"out_num_pulses":{"type":"integer","minimum":0,'
      + '"description":"number of output pulses to be generated, 0 .. '
      + 'infinite"},"output_descr":{"type":"string","description":"descriptive '
      + 'string"}},"description":"Trigger-Timestamping-Unit/IP '
      + 'configuration","title":"TTIP Configuration","required":["ttip_version"'
      + ',"num_channel","ext_channel","ext_signal","ext_delay","ext_subdivider"'
      + ',"ext_bitmask","dmi_incr","dmi_min_time","dmi_max_time","dmi_dist_per_'
      + 'tick","channel","output_descr","input_descr","output_usage","input_usa'
      + 'ge","out_polarity","out_duration","out_interval","out_delay","out_num_'
      + 'pulses","in_polarity","in_min_duration","in_max_duration","in_max_dela'
      + 'y"],"type":"object","$schema":"http://json-schema.org/draft-04/schema#'
      + '"}'
    );

    Example : (''
      + '{"in_polarity":0,"dmi_incr":0,"dmi_dist_per_tick":0.0,"ext_channel":32'
      + ',"out_duration":300,"in_max_delay":9990,"ext_subdivider":1,"out_interv'
      + 'al":10000,"ext_signal":0,"in_min_duration":0,"out_delay":0,"dmi_max_ti'
      + 'me":0,"ttip_version":1,"in_max_duration":10000,"input_usage":1,"dmi_mi'
      + 'n_time":0,"ext_bitmask":0,"num_channel":9,"out_polarity":0,"output_usa'
      + 'ge":1,"input_descr":"Port 1 - Exposure","ext_delay":0,"channel":0,"out'
      + '_num_pulses":1,"output_descr":"Port 1 - Trigger"}'
    );
  );

// Details about vertex file
const
  RDB_RIEGL_VERTEX_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.vertex_info';
    Title       : 'Vertex Information';
    Description : 'Details about vertex file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"object","$schema":"http://json-schema.org/draft-04/schema#","'
      + 'description":"Details about vertex file","title":"Vertex Information",'
      + '"properties":{"vertex_file":{"type":"object","properties":{"file_exten'
      + 'sion":{"type":"string","description":"Vertex file extension, without '
      + 'the leading dot"},"file_uuid":{"type":"string","description":"File''s '
      + 'Universally Unique Identifier (RFC '
      + '4122)"}},"required":["file_extension"]}}}'
    );

    Example : (''
      + '{"vertex_file":{"file_extension":"vtx","file_uuid":"51534d95-d71f-4f36'
      + '-ae1a-3e63a21fd1c7"}}'
    );
  );

// Details about the voxels contained in the file
const
  RDB_RIEGL_VOXEL_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.voxel_info';
    Title       : 'Voxel Information';
    Description : 'Details about the voxels contained in the file';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"$schema":"http://json-schema.org/draft-04/schema#","description":"De'
      + 'tails about the voxels contained in the file","title":"Voxel Informati'
      + 'on","type":"object","oneOf":[{"required":["size","voxel_origin","voxel'
      + '_type"],"properties":{"voxel_type":{"$ref":"#/definitions/voxel_type"}'
      + ',"shape_thresholds":{"$ref":"#/definitions/shape_thresholds"},"voxel_o'
      + 'rigin":{"$ref":"#/definitions/voxel_origin_enum"},"size":{"oneOf":[{"$'
      + 'ref":"#/definitions/voxel_size"},{"$ref":"#/definitions/voxel_size_cub'
      + 'ic"}],"description":"Size of voxels in file coordinate system."}},"add'
      + 'itionalProperties":false},{"required":["reference_point","size_llcs","'
      + 'size","voxel_origin","voxel_type"],"properties":{"shape_thresholds":{"'
      + '$ref":"#/definitions/shape_thresholds"},"voxel_origin":{"oneOf":[{"$re'
      + 'f":"#/definitions/voxel_origin_enum"},{"description":"The base point '
      + 'of the voxel grid. Used together with <tt>voxel_size</tt> and '
      + '<tt>voxel_index</tt> to compute actual point coordinates.","$ref":"#/d'
      + 'efinitions/voxel_origin_point"}]},"size_llcs":{"description":"Size of '
      + 'voxels in a locally levelled cartesian coordinate system (xyz). This '
      + 'is only used for voxels based on a map projection.","$ref":"#/definiti'
      + 'ons/voxel_size"},"voxel_type":{"$ref":"#/definitions/voxel_type"},"ref'
      + 'erence_point":{"type":"array","maxItems":2,"minItems":2,"description":'
      + '"Point in WGS84 geodetic decimal degree (EPSG:4326) that was used to '
      + 'compute the projection distortion parameters. The coefficient order is'
      + ' latitude, longitude. Only voxels with corresponding geo_tag, '
      + 'voxel_size and reference_point can be reliably processed together. '
      + 'This entry is available for voxel files in projected CRS only.","items'
      + '":{"type":"number","minimum":-180,"maximum":180}},"size":{"description'
      + '":"Size of voxels in file coordinate system.","$ref":"#/definitions/vo'
      + 'xel_size"}},"additionalProperties":false}],"definitions":{"voxel_origi'
      + 'n_enum":{"enum":["center","corner"],"default":"corner","description":"'
      + 'Defines whether the voxel''s center or a corner is placed on CRS origin'
      + ' <tt>(0/0/0)</tt>."},"edge_length":{"type":"number","minimum":0,"exclu'
      + 'siveMinimum":true,"description":"Length of voxel edge [m]."},"voxel_or'
      + 'igin_point":{"type":"array","maxItems":3,"minItems":3,"description":"O'
      + 'rigin point for all voxel indices in voxel CRS.","items":{"type":"numb'
      + 'er"}},"voxel_type":{"enum":["center","centroid","index"],"default":"ce'
      + 'ntroid","description":"Whether a point in a voxel represents its '
      + 'center or its centroid. If type is <tt>index</tt> there is no point '
      + 'but only an integer voxel index."},"voxel_size_cubic":{"type":"number"'
      + ',"$ref":"#/definitions/edge_length"},"shape_thresholds":{"type":"objec'
      + 't","properties":{"plane":{"type":"number","description":"If the '
      + 'smallest eigenvalue is smaller than the median eigenvalue * '
      + 'plane_threshold, the voxel is considered a plane.","maximum":1,"minimu'
      + 'm":0,"exclusiveMinimum":true,"exclusiveMaximum":true},"line":{"type":"'
      + 'number","minimum":1,"exclusiveMinimum":true,"description":"If the '
      + 'biggest eigenvalue is bigger than the median eigenvalue * '
      + 'line_threshold, the voxel is considered a '
      + 'line."}},"description":"Thresholds used to compute the voxel''s '
      + 'shape_id value.","required":["plane","line"]},"voxel_size":{"type":"ar'
      + 'ray","maxItems":3,"minItems":3,"description":"Size of '
      + 'voxels.","items":{"$ref":"#/definitions/edge_length"}}}}'
    );

    Example : (''
      + '{"shape_thresholds":{"plane":0.16,"line":6},"voxel_origin":"corner","s'
      + 'ize_llcs":[0.5156575252891171,0.5130835356683303,0.5143705304787237],"'
      + 'voxel_type":"centroid","reference_point":[48,16],"size":[0.59716428347'
      + '79395,0.5971642834779395,0.5143705304787237]}'
    );
  );

// Settings for waveform averaging
const
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_averaging_settings';
    Title       : 'Waveform Averaging Settings';
    Description : 'Settings for waveform averaging';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"trim":{"type":"number","minimum":0,"maximum":0.5,"defa'
      + 'ult":0,"description":"Percentage for robust averaging."},"num_shots":{'
      + '"type":"integer","minimum":1,"description":"Number of consecutive '
      + 'shots to be used for averaging."},"mta_zone":{"type":"integer","minimu'
      + 'm":1,"description":"Fixed MTA zone for '
      + 'averaging."}},"description":"Settings for waveform '
      + 'averaging","title":"Waveform Averaging Settings","required":["num_shot'
      + 's","mta_zone"],"type":"object","$schema":"http://json-schema.org/draft'
      + '-04/schema#"}'
    );

    Example : (''
      + '{"trim":0.05,"num_shots":7,"mta_zone":1}'
    );
  );

// Details about waveform files
const
  RDB_RIEGL_WAVEFORM_INFO : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_info';
    Title       : 'Waveform Information';
    Description : 'Details about waveform files';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"range_offset_waveform_samples_m":{"type":"number","des'
      + 'cription":"Calibrated device specific range offset for waveform '
      + 'samples in '
      + 'meters."},"range_offset_m":{"type":"number","description":"Calibrated '
      + 'device specific range offset for waveform analysis by system response '
      + 'fitting in meters."},"sample_data_files":{"type":"array","items":{"typ'
      + 'e":"object","properties":{"file_extension":{"type":"string","descripti'
      + 'on":"Sample data file extension, without the leading dot"},"laser_wave'
      + 'length":{"type":"number","minimum":0,"exclusiveMinimum":false,"descrip'
      + 'tion":"Laser wavelength in meters (0 = '
      + 'unknown)"},"file_uuid":{"type":"string","description":"File''s '
      + 'Universally Unique Identifier (RFC '
      + '4122)"},"sample_bits":{"maximum":32,"description":"Bitwidth of samples'
      + ' (e.g. 10 bit, 12 bit)","type":"integer","minimum":0,"exclusiveMinimum'
      + '":false,"exclusiveMaximum":false},"sample_interval":{"type":"number","'
      + 'minimum":0,"exclusiveMinimum":false,"description":"Sampling interval '
      + 'in seconds"},"channel":{"maximum":255,"description":"Sample block '
      + 'channel number (255 = invalid)","type":"integer","minimum":0,"exclusiv'
      + 'eMinimum":false,"exclusiveMaximum":false},"channel_name":{"type":"stri'
      + 'ng","description":"Sample block channel name"},"delta_st":{"type":"num'
      + 'ber","description":"reserved"}},"required":["channel","channel_name","'
      + 'sample_interval","sample_bits","laser_wavelength","delta_st","file_ext'
      + 'ension"]}},"sample_block_file":{"type":"object","properties":{"file_ex'
      + 'tension":{"type":"string","description":"Sample block file extension, '
      + 'without the leading '
      + 'dot"},"file_uuid":{"type":"string","description":"File''s Universally '
      + 'Unique Identifier (RFC '
      + '4122)"}},"required":["file_extension"]}},"description":"Details about '
      + 'waveform files","title":"Waveform Information","required":["sample_blo'
      + 'ck_file","sample_data_files"],"type":"object","$schema":"http://json-s'
      + 'chema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"range_offset_m":3.1415,"range_offset_waveform_samples_m ":7.283,"sam'
      + 'ple_data_files":[{"laser_wavelength":0,"sample_interval":1.00503e-09,"'
      + 'file_uuid":"da084413-e3e8-4655-a122-071de8490d8e","sample_bits":12,"ch'
      + 'annel":0,"file_extension":"sp0","channel_name":"high_power","delta_st"'
      + ':0},{"laser_wavelength":0,"sample_interval":1.00503e-09,"file_uuid":"9'
      + '3585b5e-5ea9-43a1-947b-e7ba3be642d2","sample_bits":12,"channel":1,"fil'
      + 'e_extension":"sp1","channel_name":"low_power","delta_st":0},{"laser_wa'
      + 'velength":0,"sample_interval":1.00503e-09,"file_uuid":"9d2298c4-1036-4'
      + '64f-b5cb-1cf8e517f3a0","sample_bits":12,"channel":5,"file_extension":"'
      + 'sp5","channel_name":"wwf","delta_st":0}],"sample_block_file":{"file_ex'
      + 'tension":"sbx","file_uuid":"93a03615-66c0-4bea-8ff8-c577378fe660"}}'
    );
  );

// Scanner settings for waveform output
const
  RDB_RIEGL_WAVEFORM_SETTINGS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.waveform_settings';
    Title       : 'Waveform Settings';
    Description : 'Scanner settings for waveform output';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"type":"array","$schema":"http://json-schema.org/draft-04/schema#","d'
      + 'escription":"Scanner settings for waveform output","title":"Waveform S'
      + 'ettings","items":{"type":"object","properties":{"pass_ampl_less":{"typ'
      + 'e":"number","description":"Threshold for amplitude less than '
      + '[dB]"},"sbl_name":{"type":"string","description":"Name of sample '
      + 'block, e.g.: wfm, '
      + 'wwf"},"enabled":{"type":"boolean","description":"Waveform output '
      + 'enabled"},"logic_expression":{"type":"string","description":"Logic '
      + 'expression of smart waveforms '
      + 'filter"},"channel_idx_mask":{"type":"integer","description":"Bit mask '
      + 'for channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = '
      + 'Bit1, '
      + '..."},"pass_dev_greater":{"type":"integer","description":"Threshold '
      + 'for deviation greater than '
      + '[1]"},"pass_ampl_greater":{"type":"number","description":"Threshold '
      + 'for amplitude greater than '
      + '[dB]"},"smart_enabled":{"type":"boolean","description":"Smart waveform'
      + ' output '
      + 'enabled"},"pass_rng_less":{"type":"number","description":"Threshold '
      + 'for range less than '
      + '[m]"},"pass_rng_greater":{"type":"number","description":"Threshold for'
      + ' range greater than '
      + '[m]"},"pass_dev_less":{"type":"integer","description":"Threshold for '
      + 'deviation less than '
      + '[1]"}},"required":["sbl_name","enabled","channel_idx_mask"]}}'
    );

    Example : (''
      + '[{"pass_ampl_less":5.0,"sbl_name":"wfm","enabled":true,"pass_ampl_grea'
      + 'ter":1.0,"smart_enabled":true,"pass_rng_less":13.11,"pass_rng_greater"'
      + ':9.27,"channel_idx_mask":11},{"sbl_name":"wwf","enabled":false,"channe'
      + 'l_idx_mask":32}]'
    );
  );

// Window analysis data estimated from scandata and resulting filter parameters
const
  RDB_RIEGL_WINDOW_ANALYSIS : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_analysis';
    Title       : 'Window Analysis';
    Description : 'Window analysis data estimated from scandata and resulting filter parameters';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"filter":{"type":"object","properties":{"angle":{"type"'
      + ':"array","description":"[deg]","items":{"type":"number"}},"range_max":'
      + '{"type":"array","description":"[m]","items":{"type":"number"}},"range_'
      + 'min":{"type":"array","description":"[m]","items":{"type":"number"}},"a'
      + 'mplitude_max":{"type":"array","description":"[dB]","items":{"type":"nu'
      + 'mber"}}},"required":["angle","range_min","range_max","amplitude_max"]}'
      + ',"settings":{"type":"object","properties":{"amplitude":{"type":"object'
      + '","properties":{"additive_value":{"type":"number"},"sigma_factor":{"ty'
      + 'pe":"number"}},"required":["sigma_factor","additive_value"]},"range":{'
      + '"type":"object","properties":{"additive_value":{"type":"number"},"sigm'
      + 'a_factor":{"type":"number"}},"required":["sigma_factor","additive_valu'
      + 'e"]}},"required":["range","amplitude"]},"result":{"type":"object","pro'
      + 'perties":{"angle":{"type":"array","description":"[deg]","items":{"type'
      + '":"number"}},"range_mean":{"type":"array","description":"[m]","items":'
      + '{"type":"number"}},"range_sigma":{"type":"array","description":"[m]","'
      + 'items":{"type":"number"}},"timestamp":{"type":"array","description":"['
      + 's]","items":{"type":"number"}},"amplitude_mean":{"type":"array","descr'
      + 'iption":"[dB]","items":{"type":"number"}},"amplitude_offset":{"type":"'
      + 'array","description":"[dB]","items":{"type":"number"}},"amplitude_sigm'
      + 'a":{"type":"array","description":"[dB]","items":{"type":"number"}}},"r'
      + 'equired":["angle","range_mean","range_sigma","amplitude_mean","amplitu'
      + 'de_sigma","amplitude_offset"]}},"description":"Window analysis data '
      + 'estimated from scandata and resulting filter '
      + 'parameters","title":"Window Analysis","required":["result","filter","s'
      + 'ettings"],"type":"object","$schema":"http://json-schema.org/draft-04/s'
      + 'chema#"}'
    );

    Example : (''
      + '{"filter":{"angle":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7,15.8,'
      + '15.9],"range_max":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0.43,0.43'
      + '1,0.431,0.432],"range_min":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-'
      + '0.219,-0.221,-0.223,-0.225,-0.227],"amplitude_max":[8.04,8.01,7.99,7.9'
      + '6,7.93,7.9,7.88,7.85,7.83,7.8,7.78]},"settings":{"amplitude":{"additiv'
      + 'e_value":1.0,"sigma_factor":4},"range":{"additive_value":0.1,"sigma_fa'
      + 'ctor":8}},"result":{"angle":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,1'
      + '5.7,15.8,15.9],"range_mean":[0.1105621,0.1079564,0.1087088,0.1067261,0'
      + '.1054582,0.1090412,0.102871,0.1019044,0.1051523,0.1058445,0.1031261],"'
      + 'range_sigma":[0.01869652,0.02151435,0.01747969,0.01918765,0.01945776,0'
      + '.01934862,0.01955329,0.02225589,0.02229977,0.01899122,0.02009433],"tim'
      + 'estamp":[408.4441,411.4443],"amplitude_mean":[5.347396,5.263155,5.2246'
      + '55,5.179926,5.097782,5.116479,5.051756,4.983473,5.007885,5.002441,4.98'
      + '2],"amplitude_offset":[1.9,1.9],"amplitude_sigma":[0.4272844,0.4298479'
      + ',0.4236816,0.4283583,0.4362353,0.4315141,0.4373984,0.4472798,0.4346001'
      + ',0.4345487,0.4540681]}}'
    );
  );

// Correction parameters for window glass echoes
const
  RDB_RIEGL_WINDOW_ECHO_CORRECTION : TRDBPointcloudMetaDataItemInfo = (
    Name        : 'riegl.window_echo_correction';
    Title       : 'Window Echo Correction';
    Description : 'Correction parameters for window glass echoes';
    Status      : RDB_STATUS_OPTIONAL;

    Schema : (''
      + '{"properties":{"amplitude":{"type":"object","properties":{"maximum":{"'
      + 'type":"number","minimum":0.0,"description":"Maximum amplitude in '
      + 'dB"},"minimum":{"type":"number","minimum":0.0,"description":"Minimum '
      + 'amplitude in '
      + 'dB"},"entries":{"type":"integer","minimum":1,"description":"Number of '
      + 'amplitude entries"}},"description":"Amplitude axis of correction table'
      + '","required":["minimum","maximum","entries"]},"range":{"type":"object"'
      + ',"properties":{"maximum":{"type":"number","minimum":-2.0,"maximum":2.0'
      + ',"description":"Maximum range in m"},"minimum":{"type":"number","minim'
      + 'um":-2.0,"maximum":2.0,"description":"Minimum range in '
      + 'm"},"entries":{"type":"integer","minimum":1,"description":"Number of '
      + 'range entries"}},"description":"Range axis of correction table","requi'
      + 'red":["minimum","maximum","entries"]},"slices":{"type":"array","items"'
      + ':{"type":"object","properties":{"table":{"type":"array","minItems":1,"'
      + 'description":"Correction table (dimension defined by the ''amplitude'' '
      + 'and ''range'' '
      + 'objects)","items":{"type":"array","minItems":1,"description":"Table '
      + 'row (= amplitude axis)","items":{"type":"array","maxItems":3,"minItems'
      + '":3,"description":"Table column (= range '
      + 'axis)","items":{"type":"number","description":"Table cell (item 0: '
      + 'amplitude in dB, 1: range in m, 2: '
      + 'flags)"}}}},"amplitude":{"type":"number","description":"Window echo '
      + 'amplitude of slice in dB"}},"description":"Window echo correction '
      + 'parameter '
      + 'slice","required":["amplitude","table"]}}},"description":"Correction '
      + 'parameters for window glass echoes","title":"Window Echo Correction","'
      + 'required":["amplitude","range","slices"],"type":"object","$schema":"ht'
      + 'tp://json-schema.org/draft-04/schema#"}'
    );

    Example : (''
      + '{"amplitude":{"maximum":20,"minimum":2,"entries":128},"range":{"maximu'
      + 'm":1.5060822940732335,"minimum":-1.5060822940732335,"entries":128},"sl'
      + 'ices":[{"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],"amplitude":1.5'
      + '},{"table":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],"amplitude":2.0}]}'
    );
  );

// Table of all meta data item details records
const
  RDB_META_DATA_ITEMS : array of PRDBPointcloudMetaDataItemInfo = nil; // filled during initialization

implementation

procedure FixStringEncoding;
begin
  // As the unit (.pas file) doesn't contain a BOM, we need to convert all strings
  // from UTF-8 to "native" encoding at runtime (tested on Delphi 7 and Delphi XE5)

  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Name)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Title)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Description)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Schema)));
  RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ANGULAR_NOTCH_FILTER.Example)));

  RDB_RIEGL_ATMOSPHERE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Name)));
  RDB_RIEGL_ATMOSPHERE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Title)));
  RDB_RIEGL_ATMOSPHERE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Description)));
  RDB_RIEGL_ATMOSPHERE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Schema)));
  RDB_RIEGL_ATMOSPHERE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ATMOSPHERE.Example)));

  RDB_RIEGL_BEAM_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Name)));
  RDB_RIEGL_BEAM_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Title)));
  RDB_RIEGL_BEAM_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Description)));
  RDB_RIEGL_BEAM_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Schema)));
  RDB_RIEGL_BEAM_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_BEAM_GEOMETRY.Example)));

  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Name)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Title)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Description)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_CATALOG.Example)));

  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Name)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Title)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Description)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Schema)));
  RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE.Example)));

  RDB_RIEGL_DETECTION_PROBABILITY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Name)));
  RDB_RIEGL_DETECTION_PROBABILITY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Title)));
  RDB_RIEGL_DETECTION_PROBABILITY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Description)));
  RDB_RIEGL_DETECTION_PROBABILITY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Schema)));
  RDB_RIEGL_DETECTION_PROBABILITY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DETECTION_PROBABILITY.Example)));

  RDB_RIEGL_DEVICE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Name)));
  RDB_RIEGL_DEVICE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Title)));
  RDB_RIEGL_DEVICE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Description)));
  RDB_RIEGL_DEVICE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Schema)));
  RDB_RIEGL_DEVICE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY.Example)));

  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Name)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Title)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Description)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Schema)));
  RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL.Example)));

  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Name)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Title)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Description)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Schema)));
  RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICE_OUTPUT_LIMITS.Example)));

  RDB_RIEGL_DEVICES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Name)));
  RDB_RIEGL_DEVICES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Title)));
  RDB_RIEGL_DEVICES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Description)));
  RDB_RIEGL_DEVICES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Schema)));
  RDB_RIEGL_DEVICES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_DEVICES.Example)));

  RDB_RIEGL_ECHO_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Name)));
  RDB_RIEGL_ECHO_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Title)));
  RDB_RIEGL_ECHO_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Description)));
  RDB_RIEGL_ECHO_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Schema)));
  RDB_RIEGL_ECHO_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ECHO_INFO.Example)));

  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Name)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Title)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Description)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Schema)));
  RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_EXPONENTIAL_DECOMPOSITION.Example)));

  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Name)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Title)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Description)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Schema)));
  RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GAUSSIAN_DECOMPOSITION.Example)));

  RDB_RIEGL_GEO_TAG.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Name)));
  RDB_RIEGL_GEO_TAG.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Title)));
  RDB_RIEGL_GEO_TAG.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Description)));
  RDB_RIEGL_GEO_TAG.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Schema)));
  RDB_RIEGL_GEO_TAG.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEO_TAG.Example)));

  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Name)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Title)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Description)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Schema)));
  RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOMETRIC_SCALE_FACTOR.Example)));

  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Name)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Title)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Description)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Schema)));
  RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_GEOREFERENCING_PARAMETERS.Example)));

  RDB_RIEGL_ITEM_NAMES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Name)));
  RDB_RIEGL_ITEM_NAMES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Title)));
  RDB_RIEGL_ITEM_NAMES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Description)));
  RDB_RIEGL_ITEM_NAMES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Schema)));
  RDB_RIEGL_ITEM_NAMES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_ITEM_NAMES.Example)));

  RDB_RIEGL_LICENSES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Name)));
  RDB_RIEGL_LICENSES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Title)));
  RDB_RIEGL_LICENSES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Description)));
  RDB_RIEGL_LICENSES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Schema)));
  RDB_RIEGL_LICENSES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_LICENSES.Example)));

  RDB_RIEGL_MTA_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Name)));
  RDB_RIEGL_MTA_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Title)));
  RDB_RIEGL_MTA_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Description)));
  RDB_RIEGL_MTA_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Schema)));
  RDB_RIEGL_MTA_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_MTA_SETTINGS.Example)));

  RDB_RIEGL_NEAR_RANGE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Name)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Title)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Description)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Schema)));
  RDB_RIEGL_NEAR_RANGE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NEAR_RANGE_CORRECTION.Example)));

  RDB_RIEGL_NOISE_ESTIMATES.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Name)));
  RDB_RIEGL_NOISE_ESTIMATES.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Title)));
  RDB_RIEGL_NOISE_ESTIMATES.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Description)));
  RDB_RIEGL_NOISE_ESTIMATES.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Schema)));
  RDB_RIEGL_NOISE_ESTIMATES.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOISE_ESTIMATES.Example)));

  RDB_RIEGL_NOTCH_FILTER.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Name)));
  RDB_RIEGL_NOTCH_FILTER.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Title)));
  RDB_RIEGL_NOTCH_FILTER.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Description)));
  RDB_RIEGL_NOTCH_FILTER.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Schema)));
  RDB_RIEGL_NOTCH_FILTER.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_NOTCH_FILTER.Example)));

  RDB_RIEGL_PIXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Name)));
  RDB_RIEGL_PIXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Title)));
  RDB_RIEGL_PIXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Description)));
  RDB_RIEGL_PIXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Schema)));
  RDB_RIEGL_PIXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PIXEL_INFO.Example)));

  RDB_RIEGL_PLANE_PATCH_MATCHING.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Name)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Title)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Description)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Schema)));
  RDB_RIEGL_PLANE_PATCH_MATCHING.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_MATCHING.Example)));

  RDB_RIEGL_PLANE_PATCH_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Name)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Title)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Description)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Schema)));
  RDB_RIEGL_PLANE_PATCH_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_PATCH_STATISTICS.Example)));

  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Name)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Title)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Description)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Schema)));
  RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PLANE_SLOPE_CLASS_INFO.Example)));

  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Name)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Title)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Description)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Schema)));
  RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINT_ATTRIBUTE_GROUPS.Example)));

  RDB_RIEGL_POINTCLOUD_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Name)));
  RDB_RIEGL_POINTCLOUD_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Title)));
  RDB_RIEGL_POINTCLOUD_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Description)));
  RDB_RIEGL_POINTCLOUD_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Schema)));
  RDB_RIEGL_POINTCLOUD_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POINTCLOUD_INFO.Example)));

  RDB_RIEGL_POSE_ESTIMATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Name)));
  RDB_RIEGL_POSE_ESTIMATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Title)));
  RDB_RIEGL_POSE_ESTIMATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Description)));
  RDB_RIEGL_POSE_ESTIMATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Schema)));
  RDB_RIEGL_POSE_ESTIMATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_ESTIMATION.Example)));

  RDB_RIEGL_POSE_SENSORS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Name)));
  RDB_RIEGL_POSE_SENSORS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Title)));
  RDB_RIEGL_POSE_SENSORS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Description)));
  RDB_RIEGL_POSE_SENSORS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Schema)));
  RDB_RIEGL_POSE_SENSORS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_POSE_SENSORS.Example)));

  RDB_RIEGL_PULSE_POSITION_MODULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Name)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Title)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Description)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Schema)));
  RDB_RIEGL_PULSE_POSITION_MODULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_PULSE_POSITION_MODULATION.Example)));

  RDB_RIEGL_RANGE_STATISTICS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Name)));
  RDB_RIEGL_RANGE_STATISTICS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Title)));
  RDB_RIEGL_RANGE_STATISTICS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Description)));
  RDB_RIEGL_RANGE_STATISTICS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Schema)));
  RDB_RIEGL_RANGE_STATISTICS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RANGE_STATISTICS.Example)));

  RDB_RIEGL_RECEIVER_INTERNALS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Name)));
  RDB_RIEGL_RECEIVER_INTERNALS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Title)));
  RDB_RIEGL_RECEIVER_INTERNALS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Description)));
  RDB_RIEGL_RECEIVER_INTERNALS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Schema)));
  RDB_RIEGL_RECEIVER_INTERNALS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_RECEIVER_INTERNALS.Example)));

  RDB_RIEGL_REFLECTANCE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Name)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Title)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Description)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Schema)));
  RDB_RIEGL_REFLECTANCE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CALCULATION.Example)));

  RDB_RIEGL_REFLECTANCE_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Name)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Title)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Description)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Schema)));
  RDB_RIEGL_REFLECTANCE_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_REFLECTANCE_CORRECTION.Example)));

  RDB_RIEGL_SCAN_PATTERN.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Name)));
  RDB_RIEGL_SCAN_PATTERN.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Title)));
  RDB_RIEGL_SCAN_PATTERN.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Description)));
  RDB_RIEGL_SCAN_PATTERN.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Schema)));
  RDB_RIEGL_SCAN_PATTERN.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SCAN_PATTERN.Example)));

  RDB_RIEGL_SHOT_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Name)));
  RDB_RIEGL_SHOT_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Title)));
  RDB_RIEGL_SHOT_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Description)));
  RDB_RIEGL_SHOT_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Schema)));
  RDB_RIEGL_SHOT_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SHOT_INFO.Example)));

  RDB_RIEGL_STORED_FILTERS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Name)));
  RDB_RIEGL_STORED_FILTERS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Title)));
  RDB_RIEGL_STORED_FILTERS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Description)));
  RDB_RIEGL_STORED_FILTERS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Schema)));
  RDB_RIEGL_STORED_FILTERS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_STORED_FILTERS.Example)));

  RDB_RIEGL_SYSTEM_DESCRIPTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Name)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Title)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Description)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Schema)));
  RDB_RIEGL_SYSTEM_DESCRIPTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_SYSTEM_DESCRIPTION.Example)));

  RDB_RIEGL_TEMPERATURE_CALCULATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Name)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Title)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Description)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Schema)));
  RDB_RIEGL_TEMPERATURE_CALCULATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TEMPERATURE_CALCULATION.Example)));

  RDB_RIEGL_TIME_BASE.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Name)));
  RDB_RIEGL_TIME_BASE.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Title)));
  RDB_RIEGL_TIME_BASE.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Description)));
  RDB_RIEGL_TIME_BASE.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Schema)));
  RDB_RIEGL_TIME_BASE.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TIME_BASE.Example)));

  RDB_RIEGL_TRAJECTORY_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Name)));
  RDB_RIEGL_TRAJECTORY_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Title)));
  RDB_RIEGL_TRAJECTORY_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Description)));
  RDB_RIEGL_TRAJECTORY_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Schema)));
  RDB_RIEGL_TRAJECTORY_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TRAJECTORY_INFO.Example)));

  RDB_RIEGL_TTIP_CONFIGURATION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Name)));
  RDB_RIEGL_TTIP_CONFIGURATION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Title)));
  RDB_RIEGL_TTIP_CONFIGURATION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Description)));
  RDB_RIEGL_TTIP_CONFIGURATION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Schema)));
  RDB_RIEGL_TTIP_CONFIGURATION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_TTIP_CONFIGURATION.Example)));

  RDB_RIEGL_VERTEX_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Name)));
  RDB_RIEGL_VERTEX_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Title)));
  RDB_RIEGL_VERTEX_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Description)));
  RDB_RIEGL_VERTEX_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Schema)));
  RDB_RIEGL_VERTEX_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VERTEX_INFO.Example)));

  RDB_RIEGL_VOXEL_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Name)));
  RDB_RIEGL_VOXEL_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Title)));
  RDB_RIEGL_VOXEL_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Description)));
  RDB_RIEGL_VOXEL_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Schema)));
  RDB_RIEGL_VOXEL_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_VOXEL_INFO.Example)));

  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS.Example)));

  RDB_RIEGL_WAVEFORM_INFO.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Name)));
  RDB_RIEGL_WAVEFORM_INFO.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Title)));
  RDB_RIEGL_WAVEFORM_INFO.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Description)));
  RDB_RIEGL_WAVEFORM_INFO.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Schema)));
  RDB_RIEGL_WAVEFORM_INFO.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_INFO.Example)));

  RDB_RIEGL_WAVEFORM_SETTINGS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Name)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Title)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Description)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Schema)));
  RDB_RIEGL_WAVEFORM_SETTINGS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WAVEFORM_SETTINGS.Example)));

  RDB_RIEGL_WINDOW_ANALYSIS.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Name)));
  RDB_RIEGL_WINDOW_ANALYSIS.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Title)));
  RDB_RIEGL_WINDOW_ANALYSIS.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Description)));
  RDB_RIEGL_WINDOW_ANALYSIS.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Schema)));
  RDB_RIEGL_WINDOW_ANALYSIS.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ANALYSIS.Example)));

  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name        := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Name)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title       := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Title)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Description)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema      := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Schema)));
  RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example     := String(UTF8ToAnsi(AnsiString(RDB_RIEGL_WINDOW_ECHO_CORRECTION.Example)));
end;

procedure FillMetadataArray;
var
  i : Integer;
begin
  SetLength(RDB_META_DATA_ITEMS, 51); i := -1;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ANGULAR_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ATMOSPHERE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_BEAM_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_CATALOG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DETECTION_PROBABILITY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICE_OUTPUT_LIMITS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_DEVICES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ECHO_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_EXPONENTIAL_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GAUSSIAN_DECOMPOSITION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEO_TAG;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOMETRIC_SCALE_FACTOR;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_GEOREFERENCING_PARAMETERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_ITEM_NAMES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_LICENSES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_MTA_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NEAR_RANGE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOISE_ESTIMATES;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_NOTCH_FILTER;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PIXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_MATCHING;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_PATCH_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PLANE_SLOPE_CLASS_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINT_ATTRIBUTE_GROUPS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POINTCLOUD_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_ESTIMATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_POSE_SENSORS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_PULSE_POSITION_MODULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RANGE_STATISTICS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_RECEIVER_INTERNALS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_REFLECTANCE_CORRECTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SCAN_PATTERN;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SHOT_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_STORED_FILTERS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_SYSTEM_DESCRIPTION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TEMPERATURE_CALCULATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TIME_BASE;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TRAJECTORY_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_TTIP_CONFIGURATION;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VERTEX_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_VOXEL_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_INFO;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WAVEFORM_SETTINGS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ANALYSIS;
  Inc(i); RDB_META_DATA_ITEMS[i] := @RDB_RIEGL_WINDOW_ECHO_CORRECTION;
end;

initialization

FixStringEncoding;
FillMetadataArray;

end.
